Class: Aws::CodeBuild::Types::BatchRestrictions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Specifies restrictions for the batch build.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#compute_types_allowedArray<String>

An array of strings that specify the compute types that are allowed for the batch build. See Build environment compute types in the CodeBuild User Guide for these values.



367
368
369
370
371
372
373
# File 'lib/aws-sdk-codebuild/types.rb', line 367

class BatchRestrictions < Struct.new(
  :maximum_builds_allowed,
  :compute_types_allowed,
  :fleets_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#fleets_allowedArray<String>

An array of strings that specify the fleets that are allowed for the batch build. See Run builds on reserved capacity fleets in the CodeBuild User Guide for more information.



367
368
369
370
371
372
373
# File 'lib/aws-sdk-codebuild/types.rb', line 367

class BatchRestrictions < Struct.new(
  :maximum_builds_allowed,
  :compute_types_allowed,
  :fleets_allowed)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_builds_allowedInteger

Specifies the maximum number of builds allowed.



367
368
369
370
371
372
373
# File 'lib/aws-sdk-codebuild/types.rb', line 367

class BatchRestrictions < Struct.new(
  :maximum_builds_allowed,
  :compute_types_allowed,
  :fleets_allowed)
  SENSITIVE = []
  include Aws::Structure
end