Class: Aws::CodeBuild::Types::CreateFleetInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#base_capacity ⇒ Integer

The initial number of machines allocated to the fleet, which defines the number of builds that can run in parallel.

Returns:

  • (Integer)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#compute_type ⇒ String

Information about the compute resources the compute fleet uses. Available values include:

  • BUILD_GENERAL1_SMALL: Use up to 3 GB memory and 2 vCPUs for builds.

  • BUILD_GENERAL1_MEDIUM: Use up to 7 GB memory and 4 vCPUs for builds.

  • BUILD_GENERAL1_LARGE: Use up to 16 GB memory and 8 vCPUs for builds, depending on your environment type.

  • BUILD_GENERAL1_XLARGE: Use up to 70 GB memory and 36 vCPUs for builds, depending on your environment type.

  • BUILD_GENERAL1_2XLARGE: Use up to 145 GB memory, 72 vCPUs, and 824 GB of SSD storage for builds. This compute type supports Docker images up to 100 GB uncompressed.

If you use BUILD_GENERAL1_SMALL:

  • For environment type LINUX_CONTAINER, you can use up to 3 GB memory and 2 vCPUs for builds.

  • For environment type LINUX_GPU_CONTAINER, you can use up to 16 GB memory, 4 vCPUs, and 1 NVIDIA A10G Tensor Core GPU for builds.

  • For environment type ARM_CONTAINER, you can use up to 4 GB memory and 2 vCPUs on ARM-based processors for builds.

If you use BUILD_GENERAL1_LARGE:

  • For environment type LINUX_CONTAINER, you can use up to 15 GB memory and 8 vCPUs for builds.

  • For environment type LINUX_GPU_CONTAINER, you can use up to 255 GB memory, 32 vCPUs, and 4 NVIDIA Tesla V100 GPUs for builds.

  • For environment type ARM_CONTAINER, you can use up to 16 GB memory and 8 vCPUs on ARM-based processors for builds.

For more information, see Build environment compute types in the CodeBuild User Guide.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#environment_type ⇒ String

The environment type of the compute fleet.

  • The environment type ARM_CONTAINER is available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), Asia Pacific (Mumbai), Asia Pacific (Tokyo), Asia Pacific (Singapore), Asia Pacific (Sydney), EU (Frankfurt), and South America (São Paulo).

  • The environment type LINUX_CONTAINER is available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), EU (Frankfurt), Asia Pacific (Tokyo), Asia Pacific (Singapore), Asia Pacific (Sydney), South America (São Paulo), and Asia Pacific (Mumbai).

  • The environment type LINUX_GPU_CONTAINER is available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), EU (Frankfurt), Asia Pacific (Tokyo), and Asia Pacific (Sydney).

  • The environment type MAC_ARM is available for Medium fleets only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), Asia Pacific (Sydney), and EU (Frankfurt)

  • The environment type MAC_ARM is available for Large fleets only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), and Asia Pacific (Sydney).

  • The environment type WINDOWS_SERVER_2019_CONTAINER is available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), Asia Pacific (Sydney), Asia Pacific (Tokyo), Asia Pacific (Mumbai) and EU (Ireland).

  • The environment type WINDOWS_SERVER_2022_CONTAINER is available only in regions US East (N. Virginia), US East (Ohio), US West (Oregon), EU (Ireland), EU (Frankfurt), Asia Pacific (Sydney), Asia Pacific (Singapore), Asia Pacific (Tokyo), South America (São Paulo) and Asia Pacific (Mumbai).

For more information, see Build environment compute types in the CodeBuild user guide.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_service_role ⇒ String

The service role associated with the compute fleet. For more information, see Allow a user to add a permission policy for a fleet service role in the CodeBuild User Guide.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_id ⇒ String

The Amazon Machine Image (AMI) of the compute fleet.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the compute fleet.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#overflow_behavior ⇒ String

The compute fleet overflow behavior.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_configuration ⇒ Types::ScalingConfigurationInput

The scaling configuration of the compute fleet.



1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

A list of tag key and value pairs associated with this compute fleet.

These tags are available for use by Amazon Web Services services that support CodeBuild build project tags.

Returns:



1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_config ⇒ Types::VpcConfig

Information about the VPC configuration that CodeBuild accesses.

Returns:



1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end