Method: Aws::CodeBuild::Types::CreateFleetInput#compute_type

Defined in:
lib/aws-sdk-codebuild/types.rb

#compute_typeString

Information about the compute resources the compute fleet uses. Available values include:

  • BUILD_GENERAL1_SMALL: Use up to 3 GB memory and 2 vCPUs for builds.

  • BUILD_GENERAL1_MEDIUM: Use up to 7 GB memory and 4 vCPUs for builds.

  • BUILD_GENERAL1_LARGE: Use up to 16 GB memory and 8 vCPUs for builds, depending on your environment type.

  • BUILD_GENERAL1_XLARGE: Use up to 70 GB memory and 36 vCPUs for builds, depending on your environment type.

  • BUILD_GENERAL1_2XLARGE: Use up to 145 GB memory, 72 vCPUs, and 824 GB of SSD storage for builds. This compute type supports Docker images up to 100 GB uncompressed.

If you use BUILD_GENERAL1_SMALL:

  • For environment type LINUX_CONTAINER, you can use up to 3 GB memory and 2 vCPUs for builds.

  • For environment type LINUX_GPU_CONTAINER, you can use up to 16 GB memory, 4 vCPUs, and 1 NVIDIA A10G Tensor Core GPU for builds.

  • For environment type ARM_CONTAINER, you can use up to 4 GB memory and 2 vCPUs on ARM-based processors for builds.

If you use BUILD_GENERAL1_LARGE:

  • For environment type LINUX_CONTAINER, you can use up to 15 GB memory and 8 vCPUs for builds.

  • For environment type LINUX_GPU_CONTAINER, you can use up to 255 GB memory, 32 vCPUs, and 4 NVIDIA Tesla V100 GPUs for builds.

  • For environment type ARM_CONTAINER, you can use up to 16 GB memory and 8 vCPUs on ARM-based processors for builds.

For more information, see [Build environment compute types][1] in the *CodeBuild User Guide.*

[1]: docs.aws.amazon.com/codebuild/latest/userguide/build-env-ref-compute-types.html

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-codebuild/types.rb', line 1561

class CreateFleetInput < Struct.new(
  :name,
  :base_capacity,
  :environment_type,
  :compute_type,
  :scaling_configuration,
  :overflow_behavior,
  :vpc_config,
  :image_id,
  :fleet_service_role,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end