Class: Aws::CodeBuild::Types::CreateReportGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::CreateReportGroupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#export_config ⇒ Types::ReportExportConfig
A
ReportExportConfigobject that contains information about where the report group test results are exported. -
#name ⇒ String
The name of the report group.
-
#tags ⇒ Array<Types::Tag>
A list of tag key and value pairs associated with this report group.
-
#type ⇒ String
The type of report group.
Instance Attribute Details
#export_config ⇒ Types::ReportExportConfig
A ReportExportConfig object that contains information about where the report group test results are exported.
1745 1746 1747 1748 1749 1750 1751 1752 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1745 class CreateReportGroupInput < Struct.new( :name, :type, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the report group.
1745 1746 1747 1748 1749 1750 1751 1752 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1745 class CreateReportGroupInput < Struct.new( :name, :type, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tag key and value pairs associated with this report group.
These tags are available for use by Amazon Web Services services that support CodeBuild report group tags.
1745 1746 1747 1748 1749 1750 1751 1752 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1745 class CreateReportGroupInput < Struct.new( :name, :type, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of report group.
1745 1746 1747 1748 1749 1750 1751 1752 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1745 class CreateReportGroupInput < Struct.new( :name, :type, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |