Class: Aws::CodeBuild::Types::DebugSession

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Contains information about the debug session for a build. For more information, see Viewing a running build in Session Manager.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#session_enabled ⇒ Boolean

Specifies if session debugging is enabled for this build.

Returns:

  • (Boolean)


1922
1923
1924
1925
1926
1927
# File 'lib/aws-sdk-codebuild/types.rb', line 1922

class DebugSession < Struct.new(
  :session_enabled,
  :session_target)
  SENSITIVE = []
  include Aws::Structure
end

#session_target ⇒ String

Contains the identifier of the Session Manager session used for the build. To work with the paused build, you open this session to examine, control, and resume the build.

Returns:

  • (String)


1922
1923
1924
1925
1926
1927
# File 'lib/aws-sdk-codebuild/types.rb', line 1922

class DebugSession < Struct.new(
  :session_enabled,
  :session_target)
  SENSITIVE = []
  include Aws::Structure
end