Class: Aws::CodeBuild::Types::DescribeCodeCoveragesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::DescribeCodeCoveragesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_line_coverage_percentage ⇒ Float
The maximum line coverage percentage to report.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#min_line_coverage_percentage ⇒ Float
The minimum line coverage percentage to report.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous call toDescribeCodeCoverages. -
#report_arn ⇒ String
The ARN of the report for which test cases are returned.
-
#sort_by ⇒ String
Specifies how the results are sorted.
-
#sort_order ⇒ String
Specifies if the results are sorted in ascending or descending order.
Instance Attribute Details
#max_line_coverage_percentage ⇒ Float
The maximum line coverage percentage to report.
2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2268 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2268 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#min_line_coverage_percentage ⇒ Float
The minimum line coverage percentage to report.
2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2268 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous call to DescribeCodeCoverages. This specifies the next item to return. To return the beginning of the list, exclude this parameter.
2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2268 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#report_arn ⇒ String
The ARN of the report for which test cases are returned.
2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2268 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Specifies how the results are sorted. Possible values are:
FILE_PATH
: The results are sorted by file path.
LINE_COVERAGE_PERCENTAGE
: The results are sorted by the percentage of lines that are
covered.
2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2268 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Specifies if the results are sorted in ascending or descending order.
2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2268 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |