Class: Aws::CodeBuild::Types::DescribeTestCasesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::DescribeTestCasesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::TestCaseFilter
A
TestCaseFilterobject used to filter the returned reports. -
#max_results ⇒ Integer
The maximum number of paginated test cases returned per response.
-
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in
maxResults. -
#report_arn ⇒ String
The ARN of the report for which test cases are returned.
Instance Attribute Details
#filter ⇒ Types::TestCaseFilter
A TestCaseFilter object used to filter the returned reports.
2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2325 class DescribeTestCasesInput < Struct.new( :report_arn, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of paginated test cases returned per response. Use nextToken to iterate pages in the list of returned TestCase objects. The default value is 100.
2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2325 class DescribeTestCasesInput < Struct.new( :report_arn, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in maxResults. If there more items in the list, then a unique string called a nextToken is returned. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned.
2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2325 class DescribeTestCasesInput < Struct.new( :report_arn, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#report_arn ⇒ String
The ARN of the report for which test cases are returned.
2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2325 class DescribeTestCasesInput < Struct.new( :report_arn, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |