Class: Aws::CodeBuild::Types::EnvironmentVariable
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::EnvironmentVariable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Information about an environment variable for a build project or a build.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name or key of the environment variable.
-
#type ⇒ String
The type of environment variable.
-
#value ⇒ String
The value of the environment variable.
Instance Attribute Details
#name ⇒ String
The name or key of the environment variable.
2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2077 class EnvironmentVariable < Struct.new( :name, :value, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of environment variable. Valid values include:
-
PARAMETER_STORE: An environment variable stored in Systems Manager Parameter Store. To learn how to specify a parameter store environment variable, see [env/parameter-store][1] in the *CodeBuild User Guide*. -
PLAINTEXT: An environment variable in plain text format. This is the default value. -
SECRETS_MANAGER: An environment variable stored in Secrets Manager. To learn how to specify a secrets manager environment variable, see [env/secrets-manager][2] in the *CodeBuild User Guide*.
[1]: docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec.env.parameter-store [2]: docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec.env.secrets-manager
2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2077 class EnvironmentVariable < Struct.new( :name, :value, :type) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the environment variable.
We strongly discourage the use of PLAINTEXT environment variables to store sensitive values, especially Amazon Web Services secret key IDs and secret access keys. PLAINTEXT environment variables can be displayed in plain text using the CodeBuild console and the CLI. For sensitive values, we recommend you use an environment variable of type PARAMETER_STORE or SECRETS_MANAGER.
2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2077 class EnvironmentVariable < Struct.new( :name, :value, :type) SENSITIVE = [] include Aws::Structure end |