Class: Aws::CodeBuild::Types::ExportedEnvironmentVariable
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ExportedEnvironmentVariable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Contains information about an exported environment variable.
Exported environment variables are used in conjunction with CodePipeline to export environment variables from the current build stage to subsequent stages in the pipeline. For more information, see Working with variables in the CodePipeline User Guide.
install phase. It can be updated between the start of the install
phase and the end of the post_build phase. After the post_build
phase ends, the value of exported variables cannot change.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the exported environment variable.
-
#value ⇒ String
The value assigned to the exported environment variable.
Instance Attribute Details
#name ⇒ String
The name of the exported environment variable.
2791 2792 2793 2794 2795 2796 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2791 class ExportedEnvironmentVariable < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value assigned to the exported environment variable.
2791 2792 2793 2794 2795 2796 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2791 class ExportedEnvironmentVariable < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |