Class: Aws::CodeBuild::Types::GetReportGroupTrendInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::GetReportGroupTrendInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Note:
When making an API call, you may pass GetReportGroupTrendInput data as a hash:
{
report_group_arn: "NonEmptyString", # required
num_of_reports: 1,
trend_field: "PASS_RATE", # required, accepts PASS_RATE, DURATION, TOTAL, LINE_COVERAGE, LINES_COVERED, LINES_MISSED, BRANCH_COVERAGE, BRANCHES_COVERED, BRANCHES_MISSED
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#num_of_reports ⇒ Integer
The number of reports to analyze.
-
#report_group_arn ⇒ String
The ARN of the report group that contains the reports to analyze.
-
#trend_field ⇒ String
The test report value to accumulate.
Instance Attribute Details
#num_of_reports ⇒ Integer
The number of reports to analyze. This operation always retrieves the most recent reports.
If this parameter is omitted, the most recent 100 reports are analyzed.
2553 2554 2555 2556 2557 2558 2559 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2553 class GetReportGroupTrendInput < Struct.new( :report_group_arn, :num_of_reports, :trend_field) SENSITIVE = [] include Aws::Structure end |
#report_group_arn ⇒ String
The ARN of the report group that contains the reports to analyze.
2553 2554 2555 2556 2557 2558 2559 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2553 class GetReportGroupTrendInput < Struct.new( :report_group_arn, :num_of_reports, :trend_field) SENSITIVE = [] include Aws::Structure end |
#trend_field ⇒ String
The test report value to accumulate. This must be one of the following values:
Test reports: : DURATION
: Accumulate the test run times for the specified reports.
PASS\_RATE
: Accumulate the percentage of tests that passed for the specified
test reports.
TOTAL
: Accumulate the total number of tests for the specified test
reports.
^
Code coverage reports: : BRANCH_COVERAGE
: Accumulate the branch coverage percentages for the specified
test reports.
BRANCHES\_COVERED
: Accumulate the branches covered values for the specified test
reports.
BRANCHES\_MISSED
: Accumulate the branches missed values for the specified test
reports.
LINE\_COVERAGE
: Accumulate the line coverage percentages for the specified test
reports.
LINES\_COVERED
: Accumulate the lines covered values for the specified test
reports.
LINES\_MISSED
: Accumulate the lines not covered values for the specified test
reports.
2553 2554 2555 2556 2557 2558 2559 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2553 class GetReportGroupTrendInput < Struct.new( :report_group_arn, :num_of_reports, :trend_field) SENSITIVE = [] include Aws::Structure end |