Class: Aws::CodeBuild::Types::GetResourcePolicyInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::GetResourcePolicyInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Note:
When making an API call, you may pass GetResourcePolicyInput data as a hash:
{
resource_arn: "NonEmptyString", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The ARN of the resource that is associated with the resource policy.
Instance Attribute Details
#resource_arn ⇒ String
The ARN of the resource that is associated with the resource policy.
2591 2592 2593 2594 2595 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2591 class GetResourcePolicyInput < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |