Class: Aws::CodeBuild::Types::InvalidateProjectCacheInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::InvalidateProjectCacheInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Note:
When making an API call, you may pass InvalidateProjectCacheInput data as a hash:
{
project_name: "NonEmptyString", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#project_name ⇒ String
The name of the CodeBuild build project that the cache is reset for.
Instance Attribute Details
#project_name ⇒ String
The name of the CodeBuild build project that the cache is reset for.
2715 2716 2717 2718 2719 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2715 class InvalidateProjectCacheInput < Struct.new( :project_name) SENSITIVE = [] include Aws::Structure end |