Class: Aws::CodeBuild::Types::ListCommandExecutionsForSandboxInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:next_token]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of sandbox records to be retrieved.

Returns:

  • (Integer)


3585
3586
3587
3588
3589
3590
3591
3592
# File 'lib/aws-sdk-codebuild/types.rb', line 3585

class ListCommandExecutionsForSandboxInput < Struct.new(
  :sandbox_id,
  :max_results,
  :sort_order,
  :next_token)
  SENSITIVE = [:next_token]
  include Aws::Structure
end

#next_tokenString

The next token, if any, to get paginated results. You will get this value from previous execution of list sandboxes.

Returns:

  • (String)


3585
3586
3587
3588
3589
3590
3591
3592
# File 'lib/aws-sdk-codebuild/types.rb', line 3585

class ListCommandExecutionsForSandboxInput < Struct.new(
  :sandbox_id,
  :max_results,
  :sort_order,
  :next_token)
  SENSITIVE = [:next_token]
  include Aws::Structure
end

#sandbox_idString

A ‘sandboxId` or `sandboxArn`.

Returns:

  • (String)


3585
3586
3587
3588
3589
3590
3591
3592
# File 'lib/aws-sdk-codebuild/types.rb', line 3585

class ListCommandExecutionsForSandboxInput < Struct.new(
  :sandbox_id,
  :max_results,
  :sort_order,
  :next_token)
  SENSITIVE = [:next_token]
  include Aws::Structure
end

#sort_orderString

The order in which sandbox records should be retrieved.

Returns:

  • (String)


3585
3586
3587
3588
3589
3590
3591
3592
# File 'lib/aws-sdk-codebuild/types.rb', line 3585

class ListCommandExecutionsForSandboxInput < Struct.new(
  :sandbox_id,
  :max_results,
  :sort_order,
  :next_token)
  SENSITIVE = [:next_token]
  include Aws::Structure
end