Class: Aws::CodeBuild::Types::ListCommandExecutionsForSandboxOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ListCommandExecutionsForSandboxOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#command_executions ⇒ Array<Types::CommandExecution>
Information about the requested command executions.
-
#next_token ⇒ String
Information about the next token to get paginated results.
Instance Attribute Details
#command_executions ⇒ Array<Types::CommandExecution>
Information about the requested command executions.
3604 3605 3606 3607 3608 3609 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3604 class ListCommandExecutionsForSandboxOutput < Struct.new( :command_executions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Information about the next token to get paginated results.
3604 3605 3606 3607 3608 3609 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3604 class ListCommandExecutionsForSandboxOutput < Struct.new( :command_executions, :next_token) SENSITIVE = [] include Aws::Structure end |