Class: Aws::CodeBuild::Types::ListReportsForReportGroupOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ListReportsForReportGroupOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in
maxResults. -
#reports ⇒ Array<String>
The list of report ARNs.
Instance Attribute Details
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in maxResults. If there more items in the list, then a unique string called a nextToken is returned. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned.
3357 3358 3359 3360 3361 3362 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3357 class ListReportsForReportGroupOutput < Struct.new( :next_token, :reports) SENSITIVE = [] include Aws::Structure end |
#reports ⇒ Array<String>
The list of report ARNs.
3357 3358 3359 3360 3361 3362 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3357 class ListReportsForReportGroupOutput < Struct.new( :next_token, :reports) SENSITIVE = [] include Aws::Structure end |