Class: Aws::CodeBuild::Types::ListReportsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ListReportsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::ReportFilter
A
ReportFilterobject used to filter the returned reports. -
#max_results ⇒ Integer
The maximum number of paginated reports returned per response.
-
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in
maxResults. -
#sort_order ⇒ String
Specifies the sort order for the list of returned reports.
Instance Attribute Details
#filter ⇒ Types::ReportFilter
A ReportFilter object used to filter the returned reports.
3936 3937 3938 3939 3940 3941 3942 3943 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3936 class ListReportsInput < Struct.new( :sort_order, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of paginated reports returned per response. Use nextToken to iterate pages in the list of returned Report objects. The default value is 100.
3936 3937 3938 3939 3940 3941 3942 3943 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3936 class ListReportsInput < Struct.new( :sort_order, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in maxResults. If there more items in the list, then a unique string called a nextToken is returned. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned.
3936 3937 3938 3939 3940 3941 3942 3943 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3936 class ListReportsInput < Struct.new( :sort_order, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Specifies the sort order for the list of returned reports. Valid values are:
-
ASCENDING: return reports in chronological order based on their creation date. -
DESCENDING: return reports in the reverse chronological order based on their creation date.
3936 3937 3938 3939 3940 3941 3942 3943 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3936 class ListReportsInput < Struct.new( :sort_order, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |