Class: Aws::CodeBuild::Types::ListSandboxesForProjectInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:next_token]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of sandbox records to be retrieved.

Returns:

  • (Integer)


3988
3989
3990
3991
3992
3993
3994
3995
# File 'lib/aws-sdk-codebuild/types.rb', line 3988

class ListSandboxesForProjectInput < Struct.new(
  :project_name,
  :max_results,
  :sort_order,
  :next_token)
  SENSITIVE = [:next_token]
  include Aws::Structure
end

#next_tokenString

The next token, if any, to get paginated results. You will get this value from previous execution of list sandboxes.

Returns:

  • (String)


3988
3989
3990
3991
3992
3993
3994
3995
# File 'lib/aws-sdk-codebuild/types.rb', line 3988

class ListSandboxesForProjectInput < Struct.new(
  :project_name,
  :max_results,
  :sort_order,
  :next_token)
  SENSITIVE = [:next_token]
  include Aws::Structure
end

#project_nameString

The CodeBuild project name.

Returns:

  • (String)


3988
3989
3990
3991
3992
3993
3994
3995
# File 'lib/aws-sdk-codebuild/types.rb', line 3988

class ListSandboxesForProjectInput < Struct.new(
  :project_name,
  :max_results,
  :sort_order,
  :next_token)
  SENSITIVE = [:next_token]
  include Aws::Structure
end

#sort_orderString

The order in which sandbox records should be retrieved.

Returns:

  • (String)


3988
3989
3990
3991
3992
3993
3994
3995
# File 'lib/aws-sdk-codebuild/types.rb', line 3988

class ListSandboxesForProjectInput < Struct.new(
  :project_name,
  :max_results,
  :sort_order,
  :next_token)
  SENSITIVE = [:next_token]
  include Aws::Structure
end