Class: Aws::CodeBuild::Types::ListSharedReportGroupsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ListSharedReportGroupsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of paginated shared report groups per response.
-
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in
maxResults. -
#sort_by ⇒ String
The criterion to be used to list report groups shared with the current Amazon Web Services account or user.
-
#sort_order ⇒ String
The order in which to list shared report groups.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of paginated shared report groups per response. Use nextToken to iterate pages in the list of returned ReportGroup objects. The default value is 100.
4161 4162 4163 4164 4165 4166 4167 4168 |
# File 'lib/aws-sdk-codebuild/types.rb', line 4161 class ListSharedReportGroupsInput < Struct.new( :sort_order, :sort_by, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in maxResults. If there more items in the list, then a unique string called a nextToken is returned. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned.
4161 4162 4163 4164 4165 4166 4167 4168 |
# File 'lib/aws-sdk-codebuild/types.rb', line 4161 class ListSharedReportGroupsInput < Struct.new( :sort_order, :sort_by, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The criterion to be used to list report groups shared with the current Amazon Web Services account or user. Valid values include:
-
ARN: List based on the ARN. -
MODIFIED_TIME: List based on when information about the shared report group was last changed.
4161 4162 4163 4164 4165 4166 4167 4168 |
# File 'lib/aws-sdk-codebuild/types.rb', line 4161 class ListSharedReportGroupsInput < Struct.new( :sort_order, :sort_by, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The order in which to list shared report groups. Valid values include:
-
ASCENDING: List in ascending order. -
DESCENDING: List in descending order.
4161 4162 4163 4164 4165 4166 4167 4168 |
# File 'lib/aws-sdk-codebuild/types.rb', line 4161 class ListSharedReportGroupsInput < Struct.new( :sort_order, :sort_by, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |