Class: Aws::CodeBuild::Types::ListSharedReportGroupsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ListSharedReportGroupsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in
maxResults. -
#report_groups ⇒ Array<String>
The list of ARNs for the report groups shared with the current Amazon Web Services account or user.
Instance Attribute Details
#next_token ⇒ String
During a previous call, the maximum number of items that can be returned is the value specified in maxResults. If there more items in the list, then a unique string called a nextToken is returned. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned.
4187 4188 4189 4190 4191 4192 |
# File 'lib/aws-sdk-codebuild/types.rb', line 4187 class ListSharedReportGroupsOutput < Struct.new( :next_token, :report_groups) SENSITIVE = [] include Aws::Structure end |
#report_groups ⇒ Array<String>
The list of ARNs for the report groups shared with the current Amazon Web Services account or user.
4187 4188 4189 4190 4191 4192 |
# File 'lib/aws-sdk-codebuild/types.rb', line 4187 class ListSharedReportGroupsOutput < Struct.new( :next_token, :report_groups) SENSITIVE = [] include Aws::Structure end |