Class: Aws::CodeBuild::Types::LogsLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::LogsLocation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Information about build logs in CloudWatch Logs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_logs ⇒ Types::CloudWatchLogsConfig
Information about CloudWatch Logs for a build project.
-
#cloud_watch_logs_arn ⇒ String
The ARN of the CloudWatch Logs stream for a build execution.
-
#deep_link ⇒ String
The URL to an individual build log in CloudWatch Logs.
-
#group_name ⇒ String
The name of the CloudWatch Logs group for the build logs.
-
#s3_deep_link ⇒ String
The URL to a build log in an S3 bucket.
-
#s3_logs ⇒ Types::S3LogsConfig
Information about S3 logs for a build project.
-
#s3_logs_arn ⇒ String
The ARN of S3 logs for a build project.
-
#stream_name ⇒ String
The name of the CloudWatch Logs stream for the build logs.
Instance Attribute Details
#cloud_watch_logs ⇒ Types::CloudWatchLogsConfig
Information about CloudWatch Logs for a build project.
3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3078 class LogsLocation < Struct.new( :group_name, :stream_name, :deep_link, :s3_deep_link, :cloud_watch_logs_arn, :s3_logs_arn, :cloud_watch_logs, :s3_logs) SENSITIVE = [] include Aws::Structure end |
#cloud_watch_logs_arn ⇒ String
The ARN of the CloudWatch Logs stream for a build execution. Its
format is
arn:$\{Partition\}:logs:$\{Region\}:$\{Account\}:log-group:$\{LogGroupName\}:log-stream:$\{LogStreamName\}.
The CloudWatch Logs stream is created during the PROVISIONING phase
of a build and the ARN will not be valid until it is created. For
more information, see Resources Defined by CloudWatch Logs.
3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3078 class LogsLocation < Struct.new( :group_name, :stream_name, :deep_link, :s3_deep_link, :cloud_watch_logs_arn, :s3_logs_arn, :cloud_watch_logs, :s3_logs) SENSITIVE = [] include Aws::Structure end |
#deep_link ⇒ String
The URL to an individual build log in CloudWatch Logs. The log
stream is created during the PROVISIONING phase of a build and the
deeplink will not be valid until it is created.
3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3078 class LogsLocation < Struct.new( :group_name, :stream_name, :deep_link, :s3_deep_link, :cloud_watch_logs_arn, :s3_logs_arn, :cloud_watch_logs, :s3_logs) SENSITIVE = [] include Aws::Structure end |
#group_name ⇒ String
The name of the CloudWatch Logs group for the build logs.
3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3078 class LogsLocation < Struct.new( :group_name, :stream_name, :deep_link, :s3_deep_link, :cloud_watch_logs_arn, :s3_logs_arn, :cloud_watch_logs, :s3_logs) SENSITIVE = [] include Aws::Structure end |
#s3_deep_link ⇒ String
The URL to a build log in an S3 bucket.
3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3078 class LogsLocation < Struct.new( :group_name, :stream_name, :deep_link, :s3_deep_link, :cloud_watch_logs_arn, :s3_logs_arn, :cloud_watch_logs, :s3_logs) SENSITIVE = [] include Aws::Structure end |
#s3_logs ⇒ Types::S3LogsConfig
Information about S3 logs for a build project.
3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3078 class LogsLocation < Struct.new( :group_name, :stream_name, :deep_link, :s3_deep_link, :cloud_watch_logs_arn, :s3_logs_arn, :cloud_watch_logs, :s3_logs) SENSITIVE = [] include Aws::Structure end |
#s3_logs_arn ⇒ String
The ARN of S3 logs for a build project. Its format is
arn:$\{Partition\}:s3:::$\{BucketName\}/$\{ObjectName\}. For more
information, see Resources Defined by Amazon S3.
3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3078 class LogsLocation < Struct.new( :group_name, :stream_name, :deep_link, :s3_deep_link, :cloud_watch_logs_arn, :s3_logs_arn, :cloud_watch_logs, :s3_logs) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the CloudWatch Logs stream for the build logs.
3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3078 class LogsLocation < Struct.new( :group_name, :stream_name, :deep_link, :s3_deep_link, :cloud_watch_logs_arn, :s3_logs_arn, :cloud_watch_logs, :s3_logs) SENSITIVE = [] include Aws::Structure end |