Class: Aws::CodeBuild::Types::PutResourcePolicyInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policyString

A JSON-formatted resource policy. For more information, see Sharing a Project and Sharing a Report Group in the CodeBuild User Guide.

Returns:

  • (String)


4725
4726
4727
4728
4729
4730
# File 'lib/aws-sdk-codebuild/types.rb', line 4725

class PutResourcePolicyInput < Struct.new(
  :policy,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The ARN of the Project or ReportGroup resource you want to associate with a resource policy.

Returns:

  • (String)


4725
4726
4727
4728
4729
4730
# File 'lib/aws-sdk-codebuild/types.rb', line 4725

class PutResourcePolicyInput < Struct.new(
  :policy,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end