Class: Aws::CodeBuild::Types::ReportGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

A series of reports. Each report contains information about the results from running a series of test cases. You specify the test cases for a report group in the buildspec for a build project using one or more paths to the test case files.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the ReportGroup.



5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
# File 'lib/aws-sdk-codebuild/types.rb', line 5844

class ReportGroup < Struct.new(
  :arn,
  :name,
  :type,
  :export_config,
  :created,
  :last_modified,
  :tags,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#createdTime

The date and time this ReportGroup was created.



5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
# File 'lib/aws-sdk-codebuild/types.rb', line 5844

class ReportGroup < Struct.new(
  :arn,
  :name,
  :type,
  :export_config,
  :created,
  :last_modified,
  :tags,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#export_configTypes::ReportExportConfig

Information about the destination where the raw data of this ReportGroup is exported.



5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
# File 'lib/aws-sdk-codebuild/types.rb', line 5844

class ReportGroup < Struct.new(
  :arn,
  :name,
  :type,
  :export_config,
  :created,
  :last_modified,
  :tags,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The date and time this ReportGroup was last modified.



5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
# File 'lib/aws-sdk-codebuild/types.rb', line 5844

class ReportGroup < Struct.new(
  :arn,
  :name,
  :type,
  :export_config,
  :created,
  :last_modified,
  :tags,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the ReportGroup.



5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
# File 'lib/aws-sdk-codebuild/types.rb', line 5844

class ReportGroup < Struct.new(
  :arn,
  :name,
  :type,
  :export_config,
  :created,
  :last_modified,
  :tags,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the report group. This property is read-only.

This can be one of the following values:

ACTIVE

: The report group is active.

DELETING

: The report group is in the process of being deleted.



5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
# File 'lib/aws-sdk-codebuild/types.rb', line 5844

class ReportGroup < Struct.new(
  :arn,
  :name,
  :type,
  :export_config,
  :created,
  :last_modified,
  :tags,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tag key and value pairs associated with this report group.

These tags are available for use by Amazon Web Services services that support CodeBuild report group tags.



5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
# File 'lib/aws-sdk-codebuild/types.rb', line 5844

class ReportGroup < Struct.new(
  :arn,
  :name,
  :type,
  :export_config,
  :created,
  :last_modified,
  :tags,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the ReportGroup. This can be one of the following values:

CODE_COVERAGE

: The report group contains code coverage reports.

TEST

: The report group contains test reports.



5844
5845
5846
5847
5848
5849
5850
5851
5852
5853
5854
5855
# File 'lib/aws-sdk-codebuild/types.rb', line 5844

class ReportGroup < Struct.new(
  :arn,
  :name,
  :type,
  :export_config,
  :created,
  :last_modified,
  :tags,
  :status)
  SENSITIVE = []
  include Aws::Structure
end