Class: Aws::CodeBuild::Types::RetryBuildInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::RetryBuildInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
Specifies the identifier of the build to restart.
-
#idempotency_token ⇒ String
A unique, case sensitive identifier you provide to ensure the idempotency of the
RetryBuildrequest.
Instance Attribute Details
#id ⇒ String
Specifies the identifier of the build to restart.
5517 5518 5519 5520 5521 5522 |
# File 'lib/aws-sdk-codebuild/types.rb', line 5517 class RetryBuildInput < Struct.new( :id, :idempotency_token) SENSITIVE = [] include Aws::Structure end |
#idempotency_token ⇒ String
A unique, case sensitive identifier you provide to ensure the idempotency of the RetryBuild request. The token is included in the RetryBuild request and is valid for five minutes. If you repeat the RetryBuild request with the same token, but change a parameter, CodeBuild returns a parameter mismatch error.
5517 5518 5519 5520 5521 5522 |
# File 'lib/aws-sdk-codebuild/types.rb', line 5517 class RetryBuildInput < Struct.new( :id, :idempotency_token) SENSITIVE = [] include Aws::Structure end |