Class: Aws::CodeBuild::Types::StartBuildInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::StartBuildInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
When making an API call, you may pass StartBuildInput data as a hash:
{
project_name: "NonEmptyString", # required
secondary_sources_override: [
{
type: "CODECOMMIT", # required, accepts CODECOMMIT, CODEPIPELINE, GITHUB, S3, BITBUCKET, GITHUB_ENTERPRISE, NO_SOURCE
location: "String",
git_clone_depth: 1,
git_submodules_config: {
fetch_submodules: false, # required
},
buildspec: "String",
auth: {
type: "OAUTH", # required, accepts OAUTH
resource: "String",
},
report_build_status: false,
build_status_config: {
context: "String",
target_url: "String",
},
insecure_ssl: false,
source_identifier: "String",
},
],
secondary_sources_version_override: [
{
source_identifier: "String", # required
source_version: "String", # required
},
],
source_version: "String",
artifacts_override: {
type: "CODEPIPELINE", # required, accepts CODEPIPELINE, S3, NO_ARTIFACTS
location: "String",
path: "String",
namespace_type: "NONE", # accepts NONE, BUILD_ID
name: "String",
packaging: "NONE", # accepts NONE, ZIP
override_artifact_name: false,
encryption_disabled: false,
artifact_identifier: "String",
bucket_owner_access: "NONE", # accepts NONE, READ_ONLY, FULL
},
secondary_artifacts_override: [
{
type: "CODEPIPELINE", # required, accepts CODEPIPELINE, S3, NO_ARTIFACTS
location: "String",
path: "String",
namespace_type: "NONE", # accepts NONE, BUILD_ID
name: "String",
packaging: "NONE", # accepts NONE, ZIP
override_artifact_name: false,
encryption_disabled: false,
artifact_identifier: "String",
bucket_owner_access: "NONE", # accepts NONE, READ_ONLY, FULL
},
],
environment_variables_override: [
{
name: "NonEmptyString", # required
value: "String", # required
type: "PLAINTEXT", # accepts PLAINTEXT, PARAMETER_STORE, SECRETS_MANAGER
},
],
source_type_override: "CODECOMMIT", # accepts CODECOMMIT, CODEPIPELINE, GITHUB, S3, BITBUCKET, GITHUB_ENTERPRISE, NO_SOURCE
source_location_override: "String",
source_auth_override: {
type: "OAUTH", # required, accepts OAUTH
resource: "String",
},
git_clone_depth_override: 1,
git_submodules_config_override: {
fetch_submodules: false, # required
},
buildspec_override: "String",
insecure_ssl_override: false,
report_build_status_override: false,
build_status_config_override: {
context: "String",
target_url: "String",
},
environment_type_override: "WINDOWS_CONTAINER", # accepts WINDOWS_CONTAINER, LINUX_CONTAINER, LINUX_GPU_CONTAINER, ARM_CONTAINER, WINDOWS_SERVER_2019_CONTAINER
image_override: "NonEmptyString",
compute_type_override: "BUILD_GENERAL1_SMALL", # accepts BUILD_GENERAL1_SMALL, BUILD_GENERAL1_MEDIUM, BUILD_GENERAL1_LARGE, BUILD_GENERAL1_2XLARGE
certificate_override: "String",
cache_override: {
type: "NO_CACHE", # required, accepts NO_CACHE, S3, LOCAL
location: "String",
modes: ["LOCAL_DOCKER_LAYER_CACHE"], # accepts LOCAL_DOCKER_LAYER_CACHE, LOCAL_SOURCE_CACHE, LOCAL_CUSTOM_CACHE
},
service_role_override: "NonEmptyString",
privileged_mode_override: false,
timeout_in_minutes_override: 1,
queued_timeout_in_minutes_override: 1,
encryption_key_override: "NonEmptyString",
idempotency_token: "String",
logs_config_override: {
cloud_watch_logs: {
status: "ENABLED", # required, accepts ENABLED, DISABLED
group_name: "String",
stream_name: "String",
},
s3_logs: {
status: "ENABLED", # required, accepts ENABLED, DISABLED
location: "String",
encryption_disabled: false,
bucket_owner_access: "NONE", # accepts NONE, READ_ONLY, FULL
},
},
registry_credential_override: {
credential: "NonEmptyString", # required
credential_provider: "SECRETS_MANAGER", # required, accepts SECRETS_MANAGER
},
image_pull_credentials_type_override: "CODEBUILD", # accepts CODEBUILD, SERVICE_ROLE
debug_session_enabled: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifacts_override ⇒ Types::ProjectArtifacts
Build output artifact settings that override, for this build only, the latest ones already defined in the build project.
-
#build_status_config_override ⇒ Types::BuildStatusConfig
Contains information that defines how the build project reports the build status to the source provider.
-
#buildspec_override ⇒ String
A buildspec file declaration that overrides, for this build only, the latest one already defined in the build project.
-
#cache_override ⇒ Types::ProjectCache
A ProjectCache object specified for this build that overrides the one defined in the build project.
-
#certificate_override ⇒ String
The name of a certificate for this build that overrides the one specified in the build project.
-
#compute_type_override ⇒ String
The name of a compute type for this build that overrides the one specified in the build project.
-
#debug_session_enabled ⇒ Boolean
Specifies if session debugging is enabled for this build.
-
#encryption_key_override ⇒ String
The Key Management Service customer master key (CMK) that overrides the one specified in the build project.
-
#environment_type_override ⇒ String
A container type for this build that overrides the one specified in the build project.
-
#environment_variables_override ⇒ Array<Types::EnvironmentVariable>
A set of environment variables that overrides, for this build only, the latest ones already defined in the build project.
-
#git_clone_depth_override ⇒ Integer
The user-defined depth of history, with a minimum value of 0, that overrides, for this build only, any previous depth of history defined in the build project.
-
#git_submodules_config_override ⇒ Types::GitSubmodulesConfig
Information about the Git submodules configuration for this build of an CodeBuild build project.
-
#idempotency_token ⇒ String
A unique, case sensitive identifier you provide to ensure the idempotency of the StartBuild request.
-
#image_override ⇒ String
The name of an image for this build that overrides the one specified in the build project.
-
#image_pull_credentials_type_override ⇒ String
The type of credentials CodeBuild uses to pull images in your build.
-
#insecure_ssl_override ⇒ Boolean
Enable this flag to override the insecure SSL setting that is specified in the build project.
-
#logs_config_override ⇒ Types::LogsConfig
Log settings for this build that override the log settings defined in the build project.
-
#privileged_mode_override ⇒ Boolean
Enable this flag to override privileged mode in the build project.
-
#project_name ⇒ String
The name of the CodeBuild build project to start running a build.
-
#queued_timeout_in_minutes_override ⇒ Integer
The number of minutes a build is allowed to be queued before it times out.
-
#registry_credential_override ⇒ Types::RegistryCredential
The credentials for access to a private registry.
-
#report_build_status_override ⇒ Boolean
Set to true to report to your source provider the status of a build’s start and completion.
-
#secondary_artifacts_override ⇒ Array<Types::ProjectArtifacts>
An array of
ProjectArtifactsobjects. -
#secondary_sources_override ⇒ Array<Types::ProjectSource>
An array of
ProjectSourceobjects. -
#secondary_sources_version_override ⇒ Array<Types::ProjectSourceVersion>
An array of
ProjectSourceVersionobjects that specify one or more versions of the project’s secondary sources to be used for this build only. -
#service_role_override ⇒ String
The name of a service role for this build that overrides the one specified in the build project.
-
#source_auth_override ⇒ Types::SourceAuth
An authorization type for this build that overrides the one defined in the build project.
-
#source_location_override ⇒ String
A location that overrides, for this build, the source location for the one defined in the build project.
-
#source_type_override ⇒ String
A source input type, for this build, that overrides the source input defined in the build project.
-
#source_version ⇒ String
The version of the build input to be built, for this build only.
-
#timeout_in_minutes_override ⇒ Integer
The number of build timeout minutes, from 5 to 480 (8 hours), that overrides, for this build only, the latest setting already defined in the build project.
Instance Attribute Details
#artifacts_override ⇒ Types::ProjectArtifacts
Build output artifact settings that override, for this build only, the latest ones already defined in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#build_status_config_override ⇒ Types::BuildStatusConfig
Contains information that defines how the build project reports the build status to the source provider. This option is only used when the source provider is GITHUB, GITHUB_ENTERPRISE, or BITBUCKET.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#buildspec_override ⇒ String
A buildspec file declaration that overrides, for this build only, the latest one already defined in the build project.
If this value is set, it can be either an inline buildspec definition, the path to an alternate buildspec file relative to the value of the built-in CODEBUILD_SRC_DIR environment variable, or the path to an S3 bucket. The bucket must be in the same Amazon Web Services Region as the build project. Specify the buildspec file using its ARN (for example, arn:aws:s3:::my-codebuild-sample2/buildspec.yml). If this value is not provided or is set to an empty string, the source code must contain a buildspec file in its root directory. For more information, see [Buildspec File Name and Storage Location][1].
[1]: docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html#build-spec-ref-name-storage
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#cache_override ⇒ Types::ProjectCache
A ProjectCache object specified for this build that overrides the one defined in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#certificate_override ⇒ String
The name of a certificate for this build that overrides the one specified in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#compute_type_override ⇒ String
The name of a compute type for this build that overrides the one specified in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#debug_session_enabled ⇒ Boolean
Specifies if session debugging is enabled for this build. For more information, see [Viewing a running build in Session Manager][1].
[1]: docs.aws.amazon.com/codebuild/latest/userguide/session-manager.html
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#encryption_key_override ⇒ String
The Key Management Service customer master key (CMK) that overrides the one specified in the build project. The CMK key encrypts the build output artifacts.
<note markdown=“1”> You can use a cross-account KMS key to encrypt the build output artifacts if your service role has permission to that key.
</note>
You can specify either the Amazon Resource Name (ARN) of the CMK or, if available, the CMK’s alias (using the format ‘alias/<alias-name>`).
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#environment_type_override ⇒ String
A container type for this build that overrides the one specified in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#environment_variables_override ⇒ Array<Types::EnvironmentVariable>
A set of environment variables that overrides, for this build only, the latest ones already defined in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#git_clone_depth_override ⇒ Integer
The user-defined depth of history, with a minimum value of 0, that overrides, for this build only, any previous depth of history defined in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#git_submodules_config_override ⇒ Types::GitSubmodulesConfig
Information about the Git submodules configuration for this build of an CodeBuild build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#idempotency_token ⇒ String
A unique, case sensitive identifier you provide to ensure the idempotency of the StartBuild request. The token is included in the StartBuild request and is valid for 5 minutes. If you repeat the StartBuild request with the same token, but change a parameter, CodeBuild returns a parameter mismatch error.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#image_override ⇒ String
The name of an image for this build that overrides the one specified in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#image_pull_credentials_type_override ⇒ String
The type of credentials CodeBuild uses to pull images in your build. There are two valid values:
CODEBUILD
: Specifies that CodeBuild uses its own credentials. This requires
that you modify your ECR repository policy to trust CodeBuild's
service principal.
SERVICE_ROLE
: Specifies that CodeBuild uses your build project’s service role.
When using a cross-account or private registry image, you must use SERVICE_ROLE credentials. When using an CodeBuild curated image, you must use CODEBUILD credentials.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#insecure_ssl_override ⇒ Boolean
Enable this flag to override the insecure SSL setting that is specified in the build project. The insecure SSL setting determines whether to ignore SSL warnings while connecting to the project source code. This override applies only if the build’s source is GitHub Enterprise.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#logs_config_override ⇒ Types::LogsConfig
Log settings for this build that override the log settings defined in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#privileged_mode_override ⇒ Boolean
Enable this flag to override privileged mode in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the CodeBuild build project to start running a build.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#queued_timeout_in_minutes_override ⇒ Integer
The number of minutes a build is allowed to be queued before it times out.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#registry_credential_override ⇒ Types::RegistryCredential
The credentials for access to a private registry.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#report_build_status_override ⇒ Boolean
Set to true to report to your source provider the status of a build’s start and completion. If you use this option with a source provider other than GitHub, GitHub Enterprise, or Bitbucket, an invalidInputException is thrown.
To be able to report the build status to the source provider, the user associated with the source provider must have write access to the repo. If the user does not have write access, the build status cannot be updated. For more information, see [Source provider access][1] in the *CodeBuild User Guide*.
<note markdown=“1”> The status of a build triggered by a webhook is always reported to your source provider.
</note>
[1]: docs.aws.amazon.com/codebuild/latest/userguide/access-tokens.html
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#secondary_artifacts_override ⇒ Array<Types::ProjectArtifacts>
An array of ProjectArtifacts objects.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#secondary_sources_override ⇒ Array<Types::ProjectSource>
An array of ProjectSource objects.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#secondary_sources_version_override ⇒ Array<Types::ProjectSourceVersion>
An array of ProjectSourceVersion objects that specify one or more versions of the project’s secondary sources to be used for this build only.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#service_role_override ⇒ String
The name of a service role for this build that overrides the one specified in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#source_auth_override ⇒ Types::SourceAuth
An authorization type for this build that overrides the one defined in the build project. This override applies only if the build project’s source is BitBucket or GitHub.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#source_location_override ⇒ String
A location that overrides, for this build, the source location for the one defined in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#source_type_override ⇒ String
A source input type, for this build, that overrides the source input defined in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#source_version ⇒ String
The version of the build input to be built, for this build only. If not specified, the latest version is used. If specified, the contents depends on the source provider:
CodeCommit
: The commit ID, branch, or Git tag to use.
GitHub
: The commit ID, pull request ID, branch name, or tag name that
corresponds to the version of the source code you want to build.
If a pull request ID is specified, it must use the format
`pr/pull-request-ID` (for example `pr/25`). If a branch name is
specified, the branch's HEAD commit ID is used. If not specified,
the default branch's HEAD commit ID is used.
Bitbucket
: The commit ID, branch name, or tag name that corresponds to the
version of the source code you want to build. If a branch name is
specified, the branch's HEAD commit ID is used. If not specified,
the default branch's HEAD commit ID is used.
Amazon S3
: The version ID of the object that represents the build input ZIP
file to use.
If sourceVersion is specified at the project level, then this sourceVersion (at the build level) takes precedence.
For more information, see [Source Version Sample with CodeBuild][1] in the *CodeBuild User Guide*.
[1]: docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |
#timeout_in_minutes_override ⇒ Integer
The number of build timeout minutes, from 5 to 480 (8 hours), that overrides, for this build only, the latest setting already defined in the build project.
6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6311 class StartBuildInput < Struct.new( :project_name, :secondary_sources_override, :secondary_sources_version_override, :source_version, :artifacts_override, :secondary_artifacts_override, :environment_variables_override, :source_type_override, :source_location_override, :source_auth_override, :git_clone_depth_override, :git_submodules_config_override, :buildspec_override, :insecure_ssl_override, :report_build_status_override, :build_status_config_override, :environment_type_override, :image_override, :compute_type_override, :certificate_override, :cache_override, :service_role_override, :privileged_mode_override, :timeout_in_minutes_override, :queued_timeout_in_minutes_override, :encryption_key_override, :idempotency_token, :logs_config_override, :registry_credential_override, :image_pull_credentials_type_override, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |