Class: Aws::CodeBuild::Types::Tag
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::Tag
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
A tag, consisting of a key and a value.
This tag is available for use by Amazon Web Services services that support tags in CodeBuild.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The tag’s key.
-
#value ⇒ String
The tag’s value.
Instance Attribute Details
#key ⇒ String
The tag’s key.
7332 7333 7334 7335 7336 7337 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7332 class Tag < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The tag’s value.
7332 7333 7334 7335 7336 7337 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7332 class Tag < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |