Class: Aws::CodeBuild::Types::TestCase
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::TestCase
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Information about a test case created using a framework such as NUnit or Cucumber. A test case might be a unit test or a configuration test.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration_in_nano_seconds ⇒ Integer
The number of nanoseconds it took to run this test case.
-
#expired ⇒ Time
The date and time a test case expires.
-
#message ⇒ String
A message associated with a test case.
-
#name ⇒ String
The name of the test case.
-
#prefix ⇒ String
A string that is applied to a series of related test cases.
-
#report_arn ⇒ String
The ARN of the report to which the test case belongs.
-
#status ⇒ String
The status returned by the test case after it was run.
-
#test_raw_data_path ⇒ String
The path to the raw data file that contains the test result.
Instance Attribute Details
#duration_in_nano_seconds ⇒ Integer
The number of nanoseconds it took to run this test case.
6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6137 class TestCase < Struct.new( :report_arn, :test_raw_data_path, :prefix, :name, :status, :duration_in_nano_seconds, :message, :expired) SENSITIVE = [] include Aws::Structure end |
#expired ⇒ Time
The date and time a test case expires. A test case expires 30 days after it is created. An expired test case is not available to view in CodeBuild.
6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6137 class TestCase < Struct.new( :report_arn, :test_raw_data_path, :prefix, :name, :status, :duration_in_nano_seconds, :message, :expired) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message associated with a test case. For example, an error message or stack trace.
6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6137 class TestCase < Struct.new( :report_arn, :test_raw_data_path, :prefix, :name, :status, :duration_in_nano_seconds, :message, :expired) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the test case.
6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6137 class TestCase < Struct.new( :report_arn, :test_raw_data_path, :prefix, :name, :status, :duration_in_nano_seconds, :message, :expired) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
A string that is applied to a series of related test cases. CodeBuild generates the prefix. The prefix depends on the framework used to generate the tests.
6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6137 class TestCase < Struct.new( :report_arn, :test_raw_data_path, :prefix, :name, :status, :duration_in_nano_seconds, :message, :expired) SENSITIVE = [] include Aws::Structure end |
#report_arn ⇒ String
The ARN of the report to which the test case belongs.
6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6137 class TestCase < Struct.new( :report_arn, :test_raw_data_path, :prefix, :name, :status, :duration_in_nano_seconds, :message, :expired) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status returned by the test case after it was run. Valid
statuses are SUCCEEDED, FAILED, ERROR, SKIPPED, and
UNKNOWN.
6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6137 class TestCase < Struct.new( :report_arn, :test_raw_data_path, :prefix, :name, :status, :duration_in_nano_seconds, :message, :expired) SENSITIVE = [] include Aws::Structure end |
#test_raw_data_path ⇒ String
The path to the raw data file that contains the test result.
6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6137 class TestCase < Struct.new( :report_arn, :test_raw_data_path, :prefix, :name, :status, :duration_in_nano_seconds, :message, :expired) SENSITIVE = [] include Aws::Structure end |