Class: Aws::CodeBuild::Types::UpdateProjectInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::UpdateProjectInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
When making an API call, you may pass UpdateProjectInput data as a hash:
{
name: "NonEmptyString", # required
description: "ProjectDescription",
source: {
type: "CODECOMMIT", # required, accepts CODECOMMIT, CODEPIPELINE, GITHUB, S3, BITBUCKET, GITHUB_ENTERPRISE, NO_SOURCE
location: "String",
git_clone_depth: 1,
git_submodules_config: {
fetch_submodules: false, # required
},
buildspec: "String",
auth: {
type: "OAUTH", # required, accepts OAUTH
resource: "String",
},
report_build_status: false,
build_status_config: {
context: "String",
target_url: "String",
},
insecure_ssl: false,
source_identifier: "String",
},
secondary_sources: [
{
type: "CODECOMMIT", # required, accepts CODECOMMIT, CODEPIPELINE, GITHUB, S3, BITBUCKET, GITHUB_ENTERPRISE, NO_SOURCE
location: "String",
git_clone_depth: 1,
git_submodules_config: {
fetch_submodules: false, # required
},
buildspec: "String",
auth: {
type: "OAUTH", # required, accepts OAUTH
resource: "String",
},
report_build_status: false,
build_status_config: {
context: "String",
target_url: "String",
},
insecure_ssl: false,
source_identifier: "String",
},
],
source_version: "String",
secondary_source_versions: [
{
source_identifier: "String", # required
source_version: "String", # required
},
],
artifacts: {
type: "CODEPIPELINE", # required, accepts CODEPIPELINE, S3, NO_ARTIFACTS
location: "String",
path: "String",
namespace_type: "NONE", # accepts NONE, BUILD_ID
name: "String",
packaging: "NONE", # accepts NONE, ZIP
override_artifact_name: false,
encryption_disabled: false,
artifact_identifier: "String",
bucket_owner_access: "NONE", # accepts NONE, READ_ONLY, FULL
},
secondary_artifacts: [
{
type: "CODEPIPELINE", # required, accepts CODEPIPELINE, S3, NO_ARTIFACTS
location: "String",
path: "String",
namespace_type: "NONE", # accepts NONE, BUILD_ID
name: "String",
packaging: "NONE", # accepts NONE, ZIP
override_artifact_name: false,
encryption_disabled: false,
artifact_identifier: "String",
bucket_owner_access: "NONE", # accepts NONE, READ_ONLY, FULL
},
],
cache: {
type: "NO_CACHE", # required, accepts NO_CACHE, S3, LOCAL
location: "String",
modes: ["LOCAL_DOCKER_LAYER_CACHE"], # accepts LOCAL_DOCKER_LAYER_CACHE, LOCAL_SOURCE_CACHE, LOCAL_CUSTOM_CACHE
},
environment: {
type: "WINDOWS_CONTAINER", # required, accepts WINDOWS_CONTAINER, LINUX_CONTAINER, LINUX_GPU_CONTAINER, ARM_CONTAINER, WINDOWS_SERVER_2019_CONTAINER
image: "NonEmptyString", # required
compute_type: "BUILD_GENERAL1_SMALL", # required, accepts BUILD_GENERAL1_SMALL, BUILD_GENERAL1_MEDIUM, BUILD_GENERAL1_LARGE, BUILD_GENERAL1_2XLARGE
environment_variables: [
{
name: "NonEmptyString", # required
value: "String", # required
type: "PLAINTEXT", # accepts PLAINTEXT, PARAMETER_STORE, SECRETS_MANAGER
},
],
privileged_mode: false,
certificate: "String",
registry_credential: {
credential: "NonEmptyString", # required
credential_provider: "SECRETS_MANAGER", # required, accepts SECRETS_MANAGER
},
image_pull_credentials_type: "CODEBUILD", # accepts CODEBUILD, SERVICE_ROLE
},
service_role: "NonEmptyString",
timeout_in_minutes: 1,
queued_timeout_in_minutes: 1,
encryption_key: "NonEmptyString",
tags: [
{
key: "KeyInput",
value: "ValueInput",
},
],
vpc_config: {
vpc_id: "NonEmptyString",
subnets: ["NonEmptyString"],
security_group_ids: ["NonEmptyString"],
},
badge_enabled: false,
logs_config: {
cloud_watch_logs: {
status: "ENABLED", # required, accepts ENABLED, DISABLED
group_name: "String",
stream_name: "String",
},
s3_logs: {
status: "ENABLED", # required, accepts ENABLED, DISABLED
location: "String",
encryption_disabled: false,
bucket_owner_access: "NONE", # accepts NONE, READ_ONLY, FULL
},
},
file_system_locations: [
{
type: "EFS", # accepts EFS
location: "String",
mount_point: "String",
identifier: "String",
mount_options: "String",
},
],
build_batch_config: {
service_role: "NonEmptyString",
combine_artifacts: false,
restrictions: {
maximum_builds_allowed: 1,
compute_types_allowed: ["NonEmptyString"],
},
timeout_in_mins: 1,
batch_report_mode: "REPORT_INDIVIDUAL_BUILDS", # accepts REPORT_INDIVIDUAL_BUILDS, REPORT_AGGREGATED_BATCH
},
concurrent_build_limit: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifacts ⇒ Types::ProjectArtifacts
Information to be changed about the build output artifacts for the build project.
-
#badge_enabled ⇒ Boolean
Set this to true to generate a publicly accessible URL for your project’s build badge.
-
#build_batch_config ⇒ Types::ProjectBuildBatchConfig
Contains configuration information about a batch build project.
-
#cache ⇒ Types::ProjectCache
Stores recently used information so that it can be quickly accessed at a later time.
-
#concurrent_build_limit ⇒ Integer
The maximum number of concurrent builds that are allowed for this project.
-
#description ⇒ String
A new or replacement description of the build project.
-
#encryption_key ⇒ String
The Key Management Service customer master key (CMK) to be used for encrypting the build output artifacts.
-
#environment ⇒ Types::ProjectEnvironment
Information to be changed about the build environment for the build project.
-
#file_system_locations ⇒ Array<Types::ProjectFileSystemLocation>
An array of
ProjectFileSystemLocationobjects for a CodeBuild build project. -
#logs_config ⇒ Types::LogsConfig
Information about logs for the build project.
-
#name ⇒ String
The name of the build project.
-
#queued_timeout_in_minutes ⇒ Integer
The number of minutes a build is allowed to be queued before it times out.
-
#secondary_artifacts ⇒ Array<Types::ProjectArtifacts>
An array of
ProjectArtifactobjects. -
#secondary_source_versions ⇒ Array<Types::ProjectSourceVersion>
An array of
ProjectSourceVersionobjects. -
#secondary_sources ⇒ Array<Types::ProjectSource>
An array of
ProjectSourceobjects. -
#service_role ⇒ String
The replacement ARN of the IAM role that enables CodeBuild to interact with dependent Amazon Web Services services on behalf of the Amazon Web Services account.
-
#source ⇒ Types::ProjectSource
Information to be changed about the build input source code for the build project.
-
#source_version ⇒ String
A version of the build input to be built for this project.
-
#tags ⇒ Array<Types::Tag>
An updated list of tag key and value pairs associated with this build project.
-
#timeout_in_minutes ⇒ Integer
The replacement value in minutes, from 5 to 480 (8 hours), for CodeBuild to wait before timing out any related build that did not get marked as completed.
-
#vpc_config ⇒ Types::VpcConfig
VpcConfig enables CodeBuild to access resources in an Amazon VPC.
Instance Attribute Details
#artifacts ⇒ Types::ProjectArtifacts
Information to be changed about the build output artifacts for the build project.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#badge_enabled ⇒ Boolean
Set this to true to generate a publicly accessible URL for your project’s build badge.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#build_batch_config ⇒ Types::ProjectBuildBatchConfig
Contains configuration information about a batch build project.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#cache ⇒ Types::ProjectCache
Stores recently used information so that it can be quickly accessed at a later time.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#concurrent_build_limit ⇒ Integer
The maximum number of concurrent builds that are allowed for this project.
New builds are only started if the current number of builds is less than or equal to this limit. If the current build count meets this limit, new builds are throttled and are not run.
To remove this limit, set this value to -1.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A new or replacement description of the build project.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#encryption_key ⇒ String
The Key Management Service customer master key (CMK) to be used for encrypting the build output artifacts.
<note markdown=“1”> You can use a cross-account KMS key to encrypt the build output artifacts if your service role has permission to that key.
</note>
You can specify either the Amazon Resource Name (ARN) of the CMK or, if available, the CMK’s alias (using the format ‘alias/<alias-name>`).
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Types::ProjectEnvironment
Information to be changed about the build environment for the build project.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#file_system_locations ⇒ Array<Types::ProjectFileSystemLocation>
An array of ProjectFileSystemLocation objects for a CodeBuild build project. A ProjectFileSystemLocation object specifies the identifier, location, mountOptions, mountPoint, and type of a file system created using Amazon Elastic File System.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#logs_config ⇒ Types::LogsConfig
Information about logs for the build project. A project can create logs in CloudWatch Logs, logs in an S3 bucket, or both.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the build project.
<note markdown=“1”> You cannot change a build project’s name.
</note>
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#queued_timeout_in_minutes ⇒ Integer
The number of minutes a build is allowed to be queued before it times out.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#secondary_artifacts ⇒ Array<Types::ProjectArtifacts>
An array of ProjectArtifact objects.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#secondary_source_versions ⇒ Array<Types::ProjectSourceVersion>
An array of ProjectSourceVersion objects. If secondarySourceVersions is specified at the build level, then they take over these secondarySourceVersions (at the project level).
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#secondary_sources ⇒ Array<Types::ProjectSource>
An array of ProjectSource objects.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The replacement ARN of the IAM role that enables CodeBuild to interact with dependent Amazon Web Services services on behalf of the Amazon Web Services account.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::ProjectSource
Information to be changed about the build input source code for the build project.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#source_version ⇒ String
A version of the build input to be built for this project. If not specified, the latest version is used. If specified, it must be one of:
-
For CodeCommit: the commit ID, branch, or Git tag to use.
-
For GitHub: the commit ID, pull request ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a pull request ID is specified, it must use the format
pr/pull-request-ID(for examplepr/25). If a branch name is specified, the branch’s HEAD commit ID is used. If not specified, the default branch’s HEAD commit ID is used. -
For Bitbucket: the commit ID, branch name, or tag name that corresponds to the version of the source code you want to build. If a branch name is specified, the branch’s HEAD commit ID is used. If not specified, the default branch’s HEAD commit ID is used.
-
For Amazon S3: the version ID of the object that represents the build input ZIP file to use.
If sourceVersion is specified at the build level, then that version takes precedence over this sourceVersion (at the project level).
For more information, see [Source Version Sample with CodeBuild][1] in the *CodeBuild User Guide*.
[1]: docs.aws.amazon.com/codebuild/latest/userguide/sample-source-version.html
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An updated list of tag key and value pairs associated with this build project.
These tags are available for use by Amazon Web Services services that support CodeBuild build project tags.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#timeout_in_minutes ⇒ Integer
The replacement value in minutes, from 5 to 480 (8 hours), for CodeBuild to wait before timing out any related build that did not get marked as completed.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
VpcConfig enables CodeBuild to access resources in an Amazon VPC.
6890 6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6890 class UpdateProjectInput < Struct.new( :name, :description, :source, :secondary_sources, :source_version, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :timeout_in_minutes, :queued_timeout_in_minutes, :encryption_key, :tags, :vpc_config, :badge_enabled, :logs_config, :file_system_locations, :build_batch_config, :concurrent_build_limit) SENSITIVE = [] include Aws::Structure end |