Class: Aws::CodeBuild::Types::UpdateReportGroupInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the report group to update.

Returns:

  • (String)


7167
7168
7169
7170
7171
7172
7173
# File 'lib/aws-sdk-codebuild/types.rb', line 7167

class UpdateReportGroupInput < Struct.new(
  :arn,
  :export_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#export_configTypes::ReportExportConfig

Used to specify an updated export type. Valid values are:

  • S3: The report results are exported to an S3 bucket.

  • NO_EXPORT: The report results are not exported.



7167
7168
7169
7170
7171
7172
7173
# File 'lib/aws-sdk-codebuild/types.rb', line 7167

class UpdateReportGroupInput < Struct.new(
  :arn,
  :export_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An updated list of tag key and value pairs associated with this report group.

These tags are available for use by Amazon Web Services services that support CodeBuild report group tags.

Returns:



7167
7168
7169
7170
7171
7172
7173
# File 'lib/aws-sdk-codebuild/types.rb', line 7167

class UpdateReportGroupInput < Struct.new(
  :arn,
  :export_config,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end