Class: Aws::CodeBuild::Types::UpdateWebhookInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::UpdateWebhookInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch_filter ⇒ String
A regular expression used to determine which repository branches are built when a webhook is triggered.
-
#build_type ⇒ String
Specifies the type of build this webhook will trigger.
-
#filter_groups ⇒ Array<Array<Types::WebhookFilter>>
An array of arrays of
WebhookFilterobjects used to determine if a webhook event can trigger a build. -
#project_name ⇒ String
The name of the CodeBuild project.
-
#rotate_secret ⇒ Boolean
A boolean value that specifies whether the associated GitHub repository's secret token should be updated.
Instance Attribute Details
#branch_filter ⇒ String
A regular expression used to determine which repository branches are
built when a webhook is triggered. If the name of a branch matches
the regular expression, then it is built. If branchFilter is
empty, then all branches are built.
filterGroups instead of
branchFilter.
6928 6929 6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6928 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |
#build_type ⇒ String
Specifies the type of build this webhook will trigger.
6928 6929 6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6928 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |
#filter_groups ⇒ Array<Array<Types::WebhookFilter>>
An array of arrays of WebhookFilter objects used to determine if a
webhook event can trigger a build. A filter group must contain at
least one EVENT WebhookFilter.
6928 6929 6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6928 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the CodeBuild project.
6928 6929 6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6928 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |
#rotate_secret ⇒ Boolean
A boolean value that specifies whether the associated GitHub
repository's secret token should be updated. If you use Bitbucket
for your repository, rotateSecret is ignored.
6928 6929 6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6928 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |