Class: Aws::CodeBuild::Types::WebhookFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::WebhookFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
A filter used to determine which webhooks trigger a build.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exclude_matched_pattern ⇒ Boolean
Used to indicate that the
patterndetermines which webhook events do not trigger a build. -
#pattern ⇒ String
For a
WebHookFilterthat usesEVENTtype, a comma-separated string that specifies one or more events. -
#type ⇒ String
The type of webhook filter.
Instance Attribute Details
#exclude_matched_pattern ⇒ Boolean
Used to indicate that the pattern determines which webhook events do not trigger a build. If true, then a webhook event that does not match the pattern triggers a build. If false, then a webhook event that matches the pattern triggers a build.
8408 8409 8410 8411 8412 8413 8414 |
# File 'lib/aws-sdk-codebuild/types.rb', line 8408 class WebhookFilter < Struct.new( :type, :pattern, :exclude_matched_pattern) SENSITIVE = [] include Aws::Structure end |
#pattern ⇒ String
For a WebHookFilter that uses EVENT type, a comma-separated string that specifies one or more events. For example, the webhook filter ‘PUSH, PULL_REQUEST_CREATED, PULL_REQUEST_UPDATED` allows all push, pull request created, and pull request updated events to trigger a build.
For a WebHookFilter that uses any of the other filter types, a regular expression pattern. For example, a WebHookFilter that uses HEAD_REF for its type and the pattern ‘^refs/heads/` triggers a build when the head reference is a branch with a reference name refs/heads/branch-name.
8408 8409 8410 8411 8412 8413 8414 |
# File 'lib/aws-sdk-codebuild/types.rb', line 8408 class WebhookFilter < Struct.new( :type, :pattern, :exclude_matched_pattern) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of webhook filter. There are 11 webhook filter types: EVENT, ACTOR_ACCOUNT_ID, HEAD_REF, BASE_REF, FILE_PATH, COMMIT_MESSAGE, TAG_NAME, RELEASE_NAME, REPOSITORY_NAME, ORGANIZATION_NAME, and WORKFLOW_NAME.
-
EVENT
-
A webhook event triggers a build when the provided
patternmatches one of nine event types:PUSH,PULL_REQUEST_CREATED,PULL_REQUEST_UPDATED,PULL_REQUEST_CLOSED,PULL_REQUEST_REOPENED,PULL_REQUEST_MERGED,RELEASED,PRERELEASED, andWORKFLOW_JOB_QUEUED. TheEVENTpatterns are specified as a comma-separated string. For example, ‘PUSH, PULL_REQUEST_CREATED, PULL_REQUEST_UPDATED` filters all push, pull request created, and pull request updated events.<note markdown=“1”> Types
PULL_REQUEST_REOPENEDandWORKFLOW_JOB_QUEUEDwork with GitHub and GitHub Enterprise only. TypesRELEASEDandPRERELEASEDwork with GitHub only.</note>
-
-
ACTOR_ACCOUNT_ID
-
A webhook event triggers a build when a GitHub, GitHub Enterprise, or Bitbucket account ID matches the regular expression
pattern.
^
-
-
HEAD_REF
-
A webhook event triggers a build when the head reference matches the regular expression
pattern. For example,refs/heads/branch-nameandrefs/tags/tag-name.<note markdown=“1”> Works with GitHub and GitHub Enterprise push, GitHub and GitHub Enterprise pull request, Bitbucket push, and Bitbucket pull request events.
</note>
-
-
BASE_REF
-
A webhook event triggers a build when the base reference matches the regular expression
pattern. For example,refs/heads/branch-name.<note markdown=“1”> Works with pull request events only.
</note>
-
-
FILE_PATH
-
A webhook triggers a build when the path of a changed file matches the regular expression
pattern.<note markdown=“1”> Works with push and pull request events only.
</note>
-
-
COMMIT_MESSAGE
-
A webhook triggers a build when the head commit message matches the regular expression
pattern.<note markdown=“1”> Works with push and pull request events only.
</note>
-
-
TAG_NAME
-
A webhook triggers a build when the tag name of the release matches the regular expression
pattern.<note markdown=“1”> Works with
RELEASEDandPRERELEASEDevents only.</note>
-
-
RELEASE_NAME
-
A webhook triggers a build when the release name matches the regular expression
pattern.<note markdown=“1”> Works with
RELEASEDandPRERELEASEDevents only.</note>
-
-
REPOSITORY_NAME
-
A webhook triggers a build when the repository name matches the regular expression
pattern.<note markdown=“1”> Works with GitHub global or organization webhooks only.
</note>
-
-
ORGANIZATION_NAME
-
A webhook triggers a build when the organization name matches the regular expression
pattern.<note markdown=“1”> Works with GitHub global webhooks only.
</note>
-
-
WORKFLOW_NAME
-
A webhook triggers a build when the workflow name matches the regular expression
pattern.<note markdown=“1”> Works with
WORKFLOW_JOB_QUEUEDevents only.</note><note markdown=“1”> For CodeBuild-hosted Buildkite runner builds, WORKFLOW_NAME filters will filter by pipeline name.
</note>
-
8408 8409 8410 8411 8412 8413 8414 |
# File 'lib/aws-sdk-codebuild/types.rb', line 8408 class WebhookFilter < Struct.new( :type, :pattern, :exclude_matched_pattern) SENSITIVE = [] include Aws::Structure end |