Method: Aws::CodeBuild::Types::BuildBatch#encryption_key
- Defined in:
- lib/aws-sdk-codebuild/types.rb
#encryption_key ⇒ String
The Key Management Service customer master key (CMK) to be used for encrypting the batch build output artifacts.
<note markdown=“1”> You can use a cross-account KMS key to encrypt the build output artifacts if your service role has permission to that key.
</note>
You can specify either the Amazon Resource Name (ARN) of the CMK or, if available, the CMK’s alias (using the format ‘alias/<alias-name>`).
784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 |
# File 'lib/aws-sdk-codebuild/types.rb', line 784 class BuildBatch < Struct.new( :id, :arn, :start_time, :end_time, :current_phase, :build_batch_status, :source_version, :resolved_source_version, :project_name, :phases, :source, :secondary_sources, :secondary_source_versions, :artifacts, :secondary_artifacts, :cache, :environment, :service_role, :log_config, :build_timeout_in_minutes, :queued_timeout_in_minutes, :complete, :initiator, :vpc_config, :encryption_key, :build_batch_number, :file_system_locations, :build_batch_config, :build_groups, :debug_session_enabled) SENSITIVE = [] include Aws::Structure end |