Class: Aws::CodeBuild::Types::BuildStatusConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Contains information that defines how the CodeBuild build project reports the build status to the source provider.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#context ⇒ String

Specifies the context of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.

Bitbucket

: This parameter is used for the name parameter in the Bitbucket commit status. For more information, see build in the Bitbucket API documentation.

GitHub/GitHub Enterprise Server

: This parameter is used for the context parameter in the GitHub commit status. For more information, see Create a commit status in the GitHub developer guide.

Returns:

  • (String)


1148
1149
1150
1151
1152
1153
# File 'lib/aws-sdk-codebuild/types.rb', line 1148

class BuildStatusConfig < Struct.new(
  :context,
  :target_url)
  SENSITIVE = []
  include Aws::Structure
end

#target_url ⇒ String

Specifies the target url of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.

Bitbucket

: This parameter is used for the url parameter in the Bitbucket commit status. For more information, see build in the Bitbucket API documentation.

GitHub/GitHub Enterprise Server

: This parameter is used for the target_url parameter in the GitHub commit status. For more information, see Create a commit status in the GitHub developer guide.

Returns:

  • (String)


1148
1149
1150
1151
1152
1153
# File 'lib/aws-sdk-codebuild/types.rb', line 1148

class BuildStatusConfig < Struct.new(
  :context,
  :target_url)
  SENSITIVE = []
  include Aws::Structure
end