Class: Aws::CodeBuild::Types::BuildStatusConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Note:

When making an API call, you may pass BuildStatusConfig data as a hash:

{
  context: "String",
  target_url: "String",
}

Contains information that defines how the CodeBuild build project reports the build status to the source provider.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contextString

Specifies the context of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.

Bitbucket

: This parameter is used for the name parameter in the Bitbucket

commit status. For more information, see [build][1] in the
Bitbucket API documentation.

GitHub/GitHub Enterprise Server

: This parameter is used for the context parameter in the GitHub

commit status. For more information, see [Create a commit
status][2] in the GitHub developer guide.

[1]: developer.atlassian.com/bitbucket/api/2/reference/resource/repositories/%7Bworkspace%7D/%7Brepo_slug%7D/commit/%7Bnode%7D/statuses/build [2]: developer.github.com/v3/repos/statuses/#create-a-commit-status

Returns:

  • (String)


1213
1214
1215
1216
1217
1218
# File 'lib/aws-sdk-codebuild/types.rb', line 1213

class BuildStatusConfig < Struct.new(
  :context,
  :target_url)
  SENSITIVE = []
  include Aws::Structure
end

#target_urlString

Specifies the target url of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.

Bitbucket

: This parameter is used for the url parameter in the Bitbucket

commit status. For more information, see [build][1] in the
Bitbucket API documentation.

GitHub/GitHub Enterprise Server

: This parameter is used for the target_url parameter in the

GitHub commit status. For more information, see [Create a commit
status][2] in the GitHub developer guide.

[1]: developer.atlassian.com/bitbucket/api/2/reference/resource/repositories/%7Bworkspace%7D/%7Brepo_slug%7D/commit/%7Bnode%7D/statuses/build [2]: developer.github.com/v3/repos/statuses/#create-a-commit-status

Returns:

  • (String)


1213
1214
1215
1216
1217
1218
# File 'lib/aws-sdk-codebuild/types.rb', line 1213

class BuildStatusConfig < Struct.new(
  :context,
  :target_url)
  SENSITIVE = []
  include Aws::Structure
end