Class: Aws::CodeBuild::Types::CreateReportGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::CreateReportGroupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Note:
When making an API call, you may pass CreateReportGroupInput data as a hash:
{
name: "ReportGroupName", # required
type: "TEST", # required, accepts TEST, CODE_COVERAGE
export_config: { # required
export_config_type: "S3", # accepts S3, NO_EXPORT
s3_destination: {
bucket: "NonEmptyString",
bucket_owner: "String",
path: "String",
packaging: "ZIP", # accepts ZIP, NONE
encryption_key: "NonEmptyString",
encryption_disabled: false,
},
},
tags: [
{
key: "KeyInput",
value: "ValueInput",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#export_config ⇒ Types::ReportExportConfig
A
ReportExportConfigobject that contains information about where the report group test results are exported. -
#name ⇒ String
The name of the report group.
-
#tags ⇒ Array<Types::Tag>
A list of tag key and value pairs associated with this report group.
-
#type ⇒ String
The type of report group.
Instance Attribute Details
#export_config ⇒ Types::ReportExportConfig
A ReportExportConfig object that contains information about where the report group test results are exported.
1835 1836 1837 1838 1839 1840 1841 1842 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1835 class CreateReportGroupInput < Struct.new( :name, :type, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the report group.
1835 1836 1837 1838 1839 1840 1841 1842 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1835 class CreateReportGroupInput < Struct.new( :name, :type, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tag key and value pairs associated with this report group.
These tags are available for use by Amazon Web Services services that support CodeBuild report group tags.
1835 1836 1837 1838 1839 1840 1841 1842 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1835 class CreateReportGroupInput < Struct.new( :name, :type, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of report group.
1835 1836 1837 1838 1839 1840 1841 1842 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1835 class CreateReportGroupInput < Struct.new( :name, :type, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |