Class: Aws::CodeBuild::Types::CreateWebhookInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::CreateWebhookInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch_filter ⇒ String
A regular expression used to determine which repository branches are built when a webhook is triggered.
-
#build_type ⇒ String
Specifies the type of build this webhook will trigger.
-
#filter_groups ⇒ Array<Array<Types::WebhookFilter>>
An array of arrays of
WebhookFilterobjects used to determine which webhooks are triggered. -
#manual_creation ⇒ Boolean
If manualCreation is true, CodeBuild doesn't create a webhook in GitHub and instead returns
payloadUrlandsecretvalues for the webhook. -
#project_name ⇒ String
The name of the CodeBuild project.
-
#scope_configuration ⇒ Types::ScopeConfiguration
The scope configuration for global or organization webhooks.
Instance Attribute Details
#branch_filter ⇒ String
A regular expression used to determine which repository branches are
built when a webhook is triggered. If the name of a branch matches
the regular expression, then it is built. If branchFilter is
empty, then all branches are built.
filterGroups instead of
branchFilter.
1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1879 class CreateWebhookInput < Struct.new( :project_name, :branch_filter, :filter_groups, :build_type, :manual_creation, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#build_type ⇒ String
Specifies the type of build this webhook will trigger.
1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1879 class CreateWebhookInput < Struct.new( :project_name, :branch_filter, :filter_groups, :build_type, :manual_creation, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#filter_groups ⇒ Array<Array<Types::WebhookFilter>>
An array of arrays of WebhookFilter objects used to determine
which webhooks are triggered. At least one WebhookFilter in the
array must specify EVENT as its type.
For a build to be triggered, at least one filter group in the
filterGroups array must pass. For a filter group to pass, each of
its filters must pass.
1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1879 class CreateWebhookInput < Struct.new( :project_name, :branch_filter, :filter_groups, :build_type, :manual_creation, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#manual_creation ⇒ Boolean
If manualCreation is true, CodeBuild doesn't create a webhook in
GitHub and instead returns payloadUrl and secret values for the
webhook. The payloadUrl and secret values in the output can be
used to manually create a webhook within GitHub.
manualCreation is only available for GitHub webhooks.
1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1879 class CreateWebhookInput < Struct.new( :project_name, :branch_filter, :filter_groups, :build_type, :manual_creation, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the CodeBuild project.
1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1879 class CreateWebhookInput < Struct.new( :project_name, :branch_filter, :filter_groups, :build_type, :manual_creation, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#scope_configuration ⇒ Types::ScopeConfiguration
The scope configuration for global or organization webhooks.
1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1879 class CreateWebhookInput < Struct.new( :project_name, :branch_filter, :filter_groups, :build_type, :manual_creation, :scope_configuration) SENSITIVE = [] include Aws::Structure end |