Class: Aws::CodeBuild::Types::DescribeCodeCoveragesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::DescribeCodeCoveragesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_line_coverage_percentage ⇒ Float
The maximum line coverage percentage to report.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#min_line_coverage_percentage ⇒ Float
The minimum line coverage percentage to report.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous call toDescribeCodeCoverages. -
#report_arn ⇒ String
The ARN of the report for which test cases are returned.
-
#sort_by ⇒ String
Specifies how the results are sorted.
-
#sort_order ⇒ String
Specifies if the results are sorted in ascending or descending order.
Instance Attribute Details
#max_line_coverage_percentage ⇒ Float
The maximum line coverage percentage to report.
1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1880 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1880 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#min_line_coverage_percentage ⇒ Float
The minimum line coverage percentage to report.
1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1880 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous call to DescribeCodeCoverages. This specifies the next item to return. To return the beginning of the list, exclude this parameter.
1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1880 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#report_arn ⇒ String
The ARN of the report for which test cases are returned.
1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1880 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Specifies how the results are sorted. Possible values are:
FILE_PATH
: The results are sorted by file path.
LINE_COVERAGE_PERCENTAGE
: The results are sorted by the percentage of lines that are
covered.
1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1880 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Specifies if the results are sorted in ascending or descending order.
1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 |
# File 'lib/aws-sdk-codebuild/types.rb', line 1880 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |