Class: Aws::CodeBuild::Types::DescribeCodeCoveragesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Note:

When making an API call, you may pass DescribeCodeCoveragesInput data as a hash:

{
  report_arn: "NonEmptyString", # required
  next_token: "String",
  max_results: 1,
  sort_order: "ASCENDING", # accepts ASCENDING, DESCENDING
  sort_by: "LINE_COVERAGE_PERCENTAGE", # accepts LINE_COVERAGE_PERCENTAGE, FILE_PATH
  min_line_coverage_percentage: 1.0,
  max_line_coverage_percentage: 1.0,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_line_coverage_percentageFloat

The maximum line coverage percentage to report.

Returns:

  • (Float)


2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
# File 'lib/aws-sdk-codebuild/types.rb', line 2216

class DescribeCodeCoveragesInput < Struct.new(
  :report_arn,
  :next_token,
  :max_results,
  :sort_order,
  :sort_by,
  :min_line_coverage_percentage,
  :max_line_coverage_percentage)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return.

Returns:

  • (Integer)


2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
# File 'lib/aws-sdk-codebuild/types.rb', line 2216

class DescribeCodeCoveragesInput < Struct.new(
  :report_arn,
  :next_token,
  :max_results,
  :sort_order,
  :sort_by,
  :min_line_coverage_percentage,
  :max_line_coverage_percentage)
  SENSITIVE = []
  include Aws::Structure
end

#min_line_coverage_percentageFloat

The minimum line coverage percentage to report.

Returns:

  • (Float)


2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
# File 'lib/aws-sdk-codebuild/types.rb', line 2216

class DescribeCodeCoveragesInput < Struct.new(
  :report_arn,
  :next_token,
  :max_results,
  :sort_order,
  :sort_by,
  :min_line_coverage_percentage,
  :max_line_coverage_percentage)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value returned from a previous call to DescribeCodeCoverages. This specifies the next item to return. To return the beginning of the list, exclude this parameter.

Returns:

  • (String)


2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
# File 'lib/aws-sdk-codebuild/types.rb', line 2216

class DescribeCodeCoveragesInput < Struct.new(
  :report_arn,
  :next_token,
  :max_results,
  :sort_order,
  :sort_by,
  :min_line_coverage_percentage,
  :max_line_coverage_percentage)
  SENSITIVE = []
  include Aws::Structure
end

#report_arnString

The ARN of the report for which test cases are returned.

Returns:

  • (String)


2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
# File 'lib/aws-sdk-codebuild/types.rb', line 2216

class DescribeCodeCoveragesInput < Struct.new(
  :report_arn,
  :next_token,
  :max_results,
  :sort_order,
  :sort_by,
  :min_line_coverage_percentage,
  :max_line_coverage_percentage)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

Specifies how the results are sorted. Possible values are:

FILE_PATH

: The results are sorted by file path.

LINE_COVERAGE_PERCENTAGE

: The results are sorted by the percentage of lines that are

covered.

Returns:

  • (String)


2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
# File 'lib/aws-sdk-codebuild/types.rb', line 2216

class DescribeCodeCoveragesInput < Struct.new(
  :report_arn,
  :next_token,
  :max_results,
  :sort_order,
  :sort_by,
  :min_line_coverage_percentage,
  :max_line_coverage_percentage)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

Specifies if the results are sorted in ascending or descending order.

Returns:

  • (String)


2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
# File 'lib/aws-sdk-codebuild/types.rb', line 2216

class DescribeCodeCoveragesInput < Struct.new(
  :report_arn,
  :next_token,
  :max_results,
  :sort_order,
  :sort_by,
  :min_line_coverage_percentage,
  :max_line_coverage_percentage)
  SENSITIVE = []
  include Aws::Structure
end