Class: Aws::CodeBuild::Types::DescribeCodeCoveragesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::DescribeCodeCoveragesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
When making an API call, you may pass DescribeCodeCoveragesInput data as a hash:
{
report_arn: "NonEmptyString", # required
next_token: "String",
max_results: 1,
sort_order: "ASCENDING", # accepts ASCENDING, DESCENDING
sort_by: "LINE_COVERAGE_PERCENTAGE", # accepts LINE_COVERAGE_PERCENTAGE, FILE_PATH
min_line_coverage_percentage: 1.0,
max_line_coverage_percentage: 1.0,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_line_coverage_percentage ⇒ Float
The maximum line coverage percentage to report.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#min_line_coverage_percentage ⇒ Float
The minimum line coverage percentage to report.
-
#next_token ⇒ String
The
nextTokenvalue returned from a previous call toDescribeCodeCoverages. -
#report_arn ⇒ String
The ARN of the report for which test cases are returned.
-
#sort_by ⇒ String
Specifies how the results are sorted.
-
#sort_order ⇒ String
Specifies if the results are sorted in ascending or descending order.
Instance Attribute Details
#max_line_coverage_percentage ⇒ Float
The maximum line coverage percentage to report.
2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2216 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return.
2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2216 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#min_line_coverage_percentage ⇒ Float
The minimum line coverage percentage to report.
2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2216 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous call to DescribeCodeCoverages. This specifies the next item to return. To return the beginning of the list, exclude this parameter.
2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2216 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#report_arn ⇒ String
The ARN of the report for which test cases are returned.
2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2216 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
Specifies how the results are sorted. Possible values are:
FILE_PATH
: The results are sorted by file path.
LINE_COVERAGE_PERCENTAGE
: The results are sorted by the percentage of lines that are
covered.
2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2216 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
Specifies if the results are sorted in ascending or descending order.
2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2216 class DescribeCodeCoveragesInput < Struct.new( :report_arn, :next_token, :max_results, :sort_order, :sort_by, :min_line_coverage_percentage, :max_line_coverage_percentage) SENSITIVE = [] include Aws::Structure end |