Class: Aws::CodeBuild::Types::ExportedEnvironmentVariable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Contains information about an exported environment variable.

Exported environment variables are used in conjunction with CodePipeline to export environment variables from the current build stage to subsequent stages in the pipeline. For more information, see Working with variables in the CodePipeline User Guide.

During a build, the value of a variable is available starting with the install phase. It can be updated between the start of the install phase and the end of the post_build phase. After the post_build phase ends, the value of exported variables cannot change.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ String

The name of the exported environment variable.

Returns:

  • (String)


2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-codebuild/types.rb', line 2119

class ExportedEnvironmentVariable < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#value ⇒ String

The value assigned to the exported environment variable.

Returns:

  • (String)


2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-codebuild/types.rb', line 2119

class ExportedEnvironmentVariable < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end