Class: Aws::CodeBuild::Types::ImportSourceCredentialsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:token]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_typeString

The type of authentication used to connect to a GitHub, GitHub Enterprise, GitLab, GitLab Self Managed, or Bitbucket repository. An OAUTH connection is not supported by the API and must be created using the CodeBuild console.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-codebuild/types.rb', line 2993

class ImportSourceCredentialsInput < Struct.new(
  :username,
  :token,
  :server_type,
  :auth_type,
  :should_overwrite)
  SENSITIVE = [:token]
  include Aws::Structure
end

#server_typeString

The source provider used for this project.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-codebuild/types.rb', line 2993

class ImportSourceCredentialsInput < Struct.new(
  :username,
  :token,
  :server_type,
  :auth_type,
  :should_overwrite)
  SENSITIVE = [:token]
  include Aws::Structure
end

#should_overwriteBoolean

Set to false to prevent overwriting the repository source credentials. Set to true to overwrite the repository source credentials. The default value is true.

Returns:

  • (Boolean)


2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-codebuild/types.rb', line 2993

class ImportSourceCredentialsInput < Struct.new(
  :username,
  :token,
  :server_type,
  :auth_type,
  :should_overwrite)
  SENSITIVE = [:token]
  include Aws::Structure
end

#tokenString

For GitHub or GitHub Enterprise, this is the personal access token. For Bitbucket, this is either the access token or the app password. For the authType CODECONNECTIONS, this is the connectionArn. For the authType SECRETS_MANAGER, this is the secretArn.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-codebuild/types.rb', line 2993

class ImportSourceCredentialsInput < Struct.new(
  :username,
  :token,
  :server_type,
  :auth_type,
  :should_overwrite)
  SENSITIVE = [:token]
  include Aws::Structure
end

#usernameString

The Bitbucket username when the authType is BASIC_AUTH. This parameter is not valid for other types of source providers or connections.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-codebuild/types.rb', line 2993

class ImportSourceCredentialsInput < Struct.new(
  :username,
  :token,
  :server_type,
  :auth_type,
  :should_overwrite)
  SENSITIVE = [:token]
  include Aws::Structure
end