Class: Aws::CodeBuild::Types::ImportSourceCredentialsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ImportSourceCredentialsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:token]
Instance Attribute Summary collapse
-
#auth_type ⇒ String
The type of authentication used to connect to a GitHub, GitHub Enterprise, GitLab, GitLab Self Managed, or Bitbucket repository.
-
#server_type ⇒ String
The source provider used for this project.
-
#should_overwrite ⇒ Boolean
Set to
falseto prevent overwriting the repository source credentials. -
#token ⇒ String
For GitHub or GitHub Enterprise, this is the personal access token.
-
#username ⇒ String
The Bitbucket username when the
authTypeis BASIC_AUTH.
Instance Attribute Details
#auth_type ⇒ String
The type of authentication used to connect to a GitHub, GitHub Enterprise, GitLab, GitLab Self Managed, or Bitbucket repository. An OAUTH connection is not supported by the API and must be created using the CodeBuild console.
2802 2803 2804 2805 2806 2807 2808 2809 2810 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2802 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |
#server_type ⇒ String
The source provider used for this project.
2802 2803 2804 2805 2806 2807 2808 2809 2810 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2802 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |
#should_overwrite ⇒ Boolean
Set to false to prevent overwriting the repository source credentials. Set to true to overwrite the repository source credentials. The default value is true.
2802 2803 2804 2805 2806 2807 2808 2809 2810 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2802 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |
#token ⇒ String
For GitHub or GitHub Enterprise, this is the personal access token. For Bitbucket, this is either the access token or the app password. For the authType CODECONNECTIONS, this is the connectionArn. For the authType SECRETS_MANAGER, this is the secretArn.
2802 2803 2804 2805 2806 2807 2808 2809 2810 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2802 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |
#username ⇒ String
The Bitbucket username when the authType is BASIC_AUTH. This parameter is not valid for other types of source providers or connections.
2802 2803 2804 2805 2806 2807 2808 2809 2810 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2802 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |