Class: Aws::CodeBuild::Types::ImportSourceCredentialsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ImportSourceCredentialsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:token]
Instance Attribute Summary collapse
-
#auth_type ⇒ String
The type of authentication used to connect to a GitHub, GitHub Enterprise, or Bitbucket repository.
-
#server_type ⇒ String
The source provider used for this project.
-
#should_overwrite ⇒ Boolean
Set to
falseto prevent overwriting the repository source credentials. -
#token ⇒ String
For GitHub or GitHub Enterprise, this is the personal access token.
-
#username ⇒ String
The Bitbucket username when the
authTypeis BASIC_AUTH.
Instance Attribute Details
#auth_type ⇒ String
The type of authentication used to connect to a GitHub, GitHub Enterprise, or Bitbucket repository. An OAUTH connection is not supported by the API and must be created using the CodeBuild console.
2288 2289 2290 2291 2292 2293 2294 2295 2296 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2288 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |
#server_type ⇒ String
The source provider used for this project.
2288 2289 2290 2291 2292 2293 2294 2295 2296 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2288 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |
#should_overwrite ⇒ Boolean
Set to false to prevent overwriting the repository source credentials. Set to true to overwrite the repository source credentials. The default value is true.
2288 2289 2290 2291 2292 2293 2294 2295 2296 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2288 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |
#token ⇒ String
For GitHub or GitHub Enterprise, this is the personal access token. For Bitbucket, this is the app password.
2288 2289 2290 2291 2292 2293 2294 2295 2296 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2288 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |
#username ⇒ String
The Bitbucket username when the authType is BASIC_AUTH. This parameter is not valid for other types of source providers or connections.
2288 2289 2290 2291 2292 2293 2294 2295 2296 |
# File 'lib/aws-sdk-codebuild/types.rb', line 2288 class ImportSourceCredentialsInput < Struct.new( :username, :token, :server_type, :auth_type, :should_overwrite) SENSITIVE = [:token] include Aws::Structure end |