Class: Aws::CodeBuild::Types::ListCommandExecutionsForSandboxInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ListCommandExecutionsForSandboxInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:next_token]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of sandbox records to be retrieved.
-
#next_token ⇒ String
The next token, if any, to get paginated results.
-
#sandbox_id ⇒ String
A ‘sandboxId` or `sandboxArn`.
-
#sort_order ⇒ String
The order in which sandbox records should be retrieved.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of sandbox records to be retrieved.
3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3585 class ListCommandExecutionsForSandboxInput < Struct.new( :sandbox_id, :max_results, :sort_order, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |
#next_token ⇒ String
The next token, if any, to get paginated results. You will get this value from previous execution of list sandboxes.
3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3585 class ListCommandExecutionsForSandboxInput < Struct.new( :sandbox_id, :max_results, :sort_order, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |
#sandbox_id ⇒ String
A ‘sandboxId` or `sandboxArn`.
3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3585 class ListCommandExecutionsForSandboxInput < Struct.new( :sandbox_id, :max_results, :sort_order, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |
#sort_order ⇒ String
The order in which sandbox records should be retrieved.
3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3585 class ListCommandExecutionsForSandboxInput < Struct.new( :sandbox_id, :max_results, :sort_order, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |