Class: Aws::CodeBuild::Types::ListSandboxesForProjectInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::ListSandboxesForProjectInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:next_token]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of sandbox records to be retrieved.
-
#next_token ⇒ String
The next token, if any, to get paginated results.
-
#project_name ⇒ String
The CodeBuild project name.
-
#sort_order ⇒ String
The order in which sandbox records should be retrieved.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of sandbox records to be retrieved.
3988 3989 3990 3991 3992 3993 3994 3995 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3988 class ListSandboxesForProjectInput < Struct.new( :project_name, :max_results, :sort_order, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |
#next_token ⇒ String
The next token, if any, to get paginated results. You will get this value from previous execution of list sandboxes.
3988 3989 3990 3991 3992 3993 3994 3995 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3988 class ListSandboxesForProjectInput < Struct.new( :project_name, :max_results, :sort_order, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |
#project_name ⇒ String
The CodeBuild project name.
3988 3989 3990 3991 3992 3993 3994 3995 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3988 class ListSandboxesForProjectInput < Struct.new( :project_name, :max_results, :sort_order, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |
#sort_order ⇒ String
The order in which sandbox records should be retrieved.
3988 3989 3990 3991 3992 3993 3994 3995 |
# File 'lib/aws-sdk-codebuild/types.rb', line 3988 class ListSandboxesForProjectInput < Struct.new( :project_name, :max_results, :sort_order, :next_token) SENSITIVE = [:next_token] include Aws::Structure end |