Class: Aws::CodeBuild::Types::RetryBuildBatchInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

Specifies the identifier of the batch build to restart.

Returns:

  • (String)


5089
5090
5091
5092
5093
5094
5095
# File 'lib/aws-sdk-codebuild/types.rb', line 5089

class RetryBuildBatchInput < Struct.new(
  :id,
  :idempotency_token,
  :retry_type)
  SENSITIVE = []
  include Aws::Structure
end

#idempotency_tokenString

A unique, case sensitive identifier you provide to ensure the idempotency of the RetryBuildBatch request. The token is included in the RetryBuildBatch request and is valid for five minutes. If you repeat the RetryBuildBatch request with the same token, but change a parameter, CodeBuild returns a parameter mismatch error.

Returns:

  • (String)


5089
5090
5091
5092
5093
5094
5095
# File 'lib/aws-sdk-codebuild/types.rb', line 5089

class RetryBuildBatchInput < Struct.new(
  :id,
  :idempotency_token,
  :retry_type)
  SENSITIVE = []
  include Aws::Structure
end

#retry_typeString

Specifies the type of retry to perform.

Returns:

  • (String)


5089
5090
5091
5092
5093
5094
5095
# File 'lib/aws-sdk-codebuild/types.rb', line 5089

class RetryBuildBatchInput < Struct.new(
  :id,
  :idempotency_token,
  :retry_type)
  SENSITIVE = []
  include Aws::Structure
end