Class: Aws::CodeBuild::Types::RetryBuildBatchInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::RetryBuildBatchInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
Specifies the identifier of the batch build to restart.
-
#idempotency_token ⇒ String
A unique, case sensitive identifier you provide to ensure the idempotency of the
RetryBuildBatchrequest. -
#retry_type ⇒ String
Specifies the type of retry to perform.
Instance Attribute Details
#id ⇒ String
Specifies the identifier of the batch build to restart.
4554 4555 4556 4557 4558 4559 4560 |
# File 'lib/aws-sdk-codebuild/types.rb', line 4554 class RetryBuildBatchInput < Struct.new( :id, :idempotency_token, :retry_type) SENSITIVE = [] include Aws::Structure end |
#idempotency_token ⇒ String
A unique, case sensitive identifier you provide to ensure the idempotency of the RetryBuildBatch request. The token is included in the RetryBuildBatch request and is valid for five minutes. If you repeat the RetryBuildBatch request with the same token, but change a parameter, CodeBuild returns a parameter mismatch error.
4554 4555 4556 4557 4558 4559 4560 |
# File 'lib/aws-sdk-codebuild/types.rb', line 4554 class RetryBuildBatchInput < Struct.new( :id, :idempotency_token, :retry_type) SENSITIVE = [] include Aws::Structure end |
#retry_type ⇒ String
Specifies the type of retry to perform.
4554 4555 4556 4557 4558 4559 4560 |
# File 'lib/aws-sdk-codebuild/types.rb', line 4554 class RetryBuildBatchInput < Struct.new( :id, :idempotency_token, :retry_type) SENSITIVE = [] include Aws::Structure end |