Class: Aws::CodeBuild::Types::RetryBuildInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

Specifies the identifier of the build to restart.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-codebuild/types.rb', line 5283

class RetryBuildInput < Struct.new(
  :id,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#idempotency_tokenString

A unique, case sensitive identifier you provide to ensure the idempotency of the RetryBuild request. The token is included in the RetryBuild request and is valid for five minutes. If you repeat the RetryBuild request with the same token, but change a parameter, CodeBuild returns a parameter mismatch error.

Returns:

  • (String)


5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-codebuild/types.rb', line 5283

class RetryBuildInput < Struct.new(
  :id,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end