Class: Aws::CodeBuild::Types::RetryBuildInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::RetryBuildInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Note:
When making an API call, you may pass RetryBuildInput data as a hash:
{
id: "NonEmptyString",
idempotency_token: "String",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
Specifies the identifier of the build to restart.
-
#idempotency_token ⇒ String
A unique, case sensitive identifier you provide to ensure the idempotency of the
RetryBuildrequest.
Instance Attribute Details
#id ⇒ String
Specifies the identifier of the build to restart.
5271 5272 5273 5274 5275 5276 |
# File 'lib/aws-sdk-codebuild/types.rb', line 5271 class RetryBuildInput < Struct.new( :id, :idempotency_token) SENSITIVE = [] include Aws::Structure end |
#idempotency_token ⇒ String
A unique, case sensitive identifier you provide to ensure the idempotency of the RetryBuild request. The token is included in the RetryBuild request and is valid for five minutes. If you repeat the RetryBuild request with the same token, but change a parameter, CodeBuild returns a parameter mismatch error.
5271 5272 5273 5274 5275 5276 |
# File 'lib/aws-sdk-codebuild/types.rb', line 5271 class RetryBuildInput < Struct.new( :id, :idempotency_token) SENSITIVE = [] include Aws::Structure end |