Class: Aws::CodeBuild::Types::UpdateReportGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::UpdateReportGroupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the report group to update.
-
#export_config ⇒ Types::ReportExportConfig
Used to specify an updated export type.
-
#tags ⇒ Array<Types::Tag>
An updated list of tag key and value pairs associated with this report group.
Instance Attribute Details
#arn ⇒ String
The ARN of the report group to update.
6626 6627 6628 6629 6630 6631 6632 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6626 class UpdateReportGroupInput < Struct.new( :arn, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#export_config ⇒ Types::ReportExportConfig
Used to specify an updated export type. Valid values are:
-
S3: The report results are exported to an S3 bucket. -
NO_EXPORT: The report results are not exported.
6626 6627 6628 6629 6630 6631 6632 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6626 class UpdateReportGroupInput < Struct.new( :arn, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An updated list of tag key and value pairs associated with this report group.
These tags are available for use by Amazon Web Services services that support CodeBuild report group tags.
6626 6627 6628 6629 6630 6631 6632 |
# File 'lib/aws-sdk-codebuild/types.rb', line 6626 class UpdateReportGroupInput < Struct.new( :arn, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |