Class: Aws::CodeBuild::Types::UpdateReportGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::UpdateReportGroupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Note:
When making an API call, you may pass UpdateReportGroupInput data as a hash:
{
arn: "NonEmptyString", # required
export_config: {
export_config_type: "S3", # accepts S3, NO_EXPORT
s3_destination: {
bucket: "NonEmptyString",
bucket_owner: "String",
path: "String",
packaging: "ZIP", # accepts ZIP, NONE
encryption_key: "NonEmptyString",
encryption_disabled: false,
},
},
tags: [
{
key: "KeyInput",
value: "ValueInput",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the report group to update.
-
#export_config ⇒ Types::ReportExportConfig
Used to specify an updated export type.
-
#tags ⇒ Array<Types::Tag>
An updated list of tag key and value pairs associated with this report group.
Instance Attribute Details
#arn ⇒ String
The ARN of the report group to update.
7046 7047 7048 7049 7050 7051 7052 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7046 class UpdateReportGroupInput < Struct.new( :arn, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#export_config ⇒ Types::ReportExportConfig
Used to specify an updated export type. Valid values are:
-
S3: The report results are exported to an S3 bucket. -
NO_EXPORT: The report results are not exported.
7046 7047 7048 7049 7050 7051 7052 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7046 class UpdateReportGroupInput < Struct.new( :arn, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An updated list of tag key and value pairs associated with this report group.
These tags are available for use by Amazon Web Services services that support CodeBuild report group tags.
7046 7047 7048 7049 7050 7051 7052 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7046 class UpdateReportGroupInput < Struct.new( :arn, :export_config, :tags) SENSITIVE = [] include Aws::Structure end |