Class: Aws::CodeBuild::Types::UpdateWebhookInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::UpdateWebhookInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
When making an API call, you may pass UpdateWebhookInput data as a hash:
{
project_name: "ProjectName", # required
branch_filter: "String",
rotate_secret: false,
filter_groups: [
[
{
type: "EVENT", # required, accepts EVENT, BASE_REF, HEAD_REF, ACTOR_ACCOUNT_ID, FILE_PATH, COMMIT_MESSAGE
pattern: "String", # required
exclude_matched_pattern: false,
},
],
],
build_type: "BUILD", # accepts BUILD, BUILD_BATCH
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch_filter ⇒ String
A regular expression used to determine which repository branches are built when a webhook is triggered.
-
#build_type ⇒ String
Specifies the type of build this webhook will trigger.
-
#filter_groups ⇒ Array<Array<Types::WebhookFilter>>
An array of arrays of
WebhookFilterobjects used to determine if a webhook event can trigger a build. -
#project_name ⇒ String
The name of the CodeBuild project.
-
#rotate_secret ⇒ Boolean
A boolean value that specifies whether the associated GitHub repository’s secret token should be updated.
Instance Attribute Details
#branch_filter ⇒ String
A regular expression used to determine which repository branches are built when a webhook is triggered. If the name of a branch matches the regular expression, then it is built. If branchFilter is empty, then all branches are built.
<note markdown=“1”> It is recommended that you use filterGroups instead of branchFilter.
</note>
7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7119 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |
#build_type ⇒ String
Specifies the type of build this webhook will trigger.
7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7119 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |
#filter_groups ⇒ Array<Array<Types::WebhookFilter>>
An array of arrays of WebhookFilter objects used to determine if a webhook event can trigger a build. A filter group must contain at least one EVENT WebhookFilter.
7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7119 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the CodeBuild project.
7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7119 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |
#rotate_secret ⇒ Boolean
A boolean value that specifies whether the associated GitHub repository’s secret token should be updated. If you use Bitbucket for your repository, rotateSecret is ignored.
7119 7120 7121 7122 7123 7124 7125 7126 7127 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7119 class UpdateWebhookInput < Struct.new( :project_name, :branch_filter, :rotate_secret, :filter_groups, :build_type) SENSITIVE = [] include Aws::Structure end |