Class: Aws::CodeBuild::Types::Webhook
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeBuild::Types::Webhook
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codebuild/types.rb
Overview
Information about a webhook that connects repository events to a build project in CodeBuild.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch_filter ⇒ String
A regular expression used to determine which repository branches are built when a webhook is triggered.
-
#build_type ⇒ String
Specifies the type of build this webhook will trigger.
-
#filter_groups ⇒ Array<Array<Types::WebhookFilter>>
An array of arrays of
WebhookFilterobjects used to determine which webhooks are triggered. -
#last_modified_secret ⇒ Time
A timestamp that indicates the last time a repository's secret token was modified.
-
#manual_creation ⇒ Boolean
If manualCreation is true, CodeBuild doesn't create a webhook in GitHub and instead returns
payloadUrlandsecretvalues for the webhook. -
#payload_url ⇒ String
The CodeBuild endpoint where webhook events are sent.
-
#scope_configuration ⇒ Types::ScopeConfiguration
The scope configuration for global or organization webhooks.
-
#secret ⇒ String
The secret token of the associated repository.
-
#url ⇒ String
The URL to the webhook.
Instance Attribute Details
#branch_filter ⇒ String
A regular expression used to determine which repository branches are
built when a webhook is triggered. If the name of a branch matches
the regular expression, then it is built. If branchFilter is
empty, then all branches are built.
filterGroups instead of
branchFilter.
7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7047 class Webhook < Struct.new( :url, :payload_url, :secret, :branch_filter, :filter_groups, :build_type, :manual_creation, :last_modified_secret, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#build_type ⇒ String
Specifies the type of build this webhook will trigger.
7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7047 class Webhook < Struct.new( :url, :payload_url, :secret, :branch_filter, :filter_groups, :build_type, :manual_creation, :last_modified_secret, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#filter_groups ⇒ Array<Array<Types::WebhookFilter>>
An array of arrays of WebhookFilter objects used to determine
which webhooks are triggered. At least one WebhookFilter in the
array must specify EVENT as its type.
For a build to be triggered, at least one filter group in the
filterGroups array must pass. For a filter group to pass, each of
its filters must pass.
7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7047 class Webhook < Struct.new( :url, :payload_url, :secret, :branch_filter, :filter_groups, :build_type, :manual_creation, :last_modified_secret, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#last_modified_secret ⇒ Time
A timestamp that indicates the last time a repository's secret token was modified.
7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7047 class Webhook < Struct.new( :url, :payload_url, :secret, :branch_filter, :filter_groups, :build_type, :manual_creation, :last_modified_secret, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#manual_creation ⇒ Boolean
If manualCreation is true, CodeBuild doesn't create a webhook in
GitHub and instead returns payloadUrl and secret values for the
webhook. The payloadUrl and secret values in the output can be
used to manually create a webhook within GitHub.
7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7047 class Webhook < Struct.new( :url, :payload_url, :secret, :branch_filter, :filter_groups, :build_type, :manual_creation, :last_modified_secret, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#payload_url ⇒ String
The CodeBuild endpoint where webhook events are sent.
7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7047 class Webhook < Struct.new( :url, :payload_url, :secret, :branch_filter, :filter_groups, :build_type, :manual_creation, :last_modified_secret, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#scope_configuration ⇒ Types::ScopeConfiguration
The scope configuration for global or organization webhooks.
7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7047 class Webhook < Struct.new( :url, :payload_url, :secret, :branch_filter, :filter_groups, :build_type, :manual_creation, :last_modified_secret, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#secret ⇒ String
The secret token of the associated repository.
secret.
7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7047 class Webhook < Struct.new( :url, :payload_url, :secret, :branch_filter, :filter_groups, :build_type, :manual_creation, :last_modified_secret, :scope_configuration) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL to the webhook.
7047 7048 7049 7050 7051 7052 7053 7054 7055 7056 7057 7058 7059 |
# File 'lib/aws-sdk-codebuild/types.rb', line 7047 class Webhook < Struct.new( :url, :payload_url, :secret, :branch_filter, :filter_groups, :build_type, :manual_creation, :last_modified_secret, :scope_configuration) SENSITIVE = [] include Aws::Structure end |