Class: Aws::CodeBuild::Types::WebhookFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codebuild/types.rb

Overview

Note:

When making an API call, you may pass WebhookFilter data as a hash:

{
  type: "EVENT", # required, accepts EVENT, BASE_REF, HEAD_REF, ACTOR_ACCOUNT_ID, FILE_PATH, COMMIT_MESSAGE
  pattern: "String", # required
  exclude_matched_pattern: false,
}

A filter used to determine which webhooks trigger a build.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#exclude_matched_patternBoolean

Used to indicate that the pattern determines which webhook events do not trigger a build. If true, then a webhook event that does not match the pattern triggers a build. If false, then a webhook event that matches the pattern triggers a build.

Returns:

  • (Boolean)


7341
7342
7343
7344
7345
7346
7347
# File 'lib/aws-sdk-codebuild/types.rb', line 7341

class WebhookFilter < Struct.new(
  :type,
  :pattern,
  :exclude_matched_pattern)
  SENSITIVE = []
  include Aws::Structure
end

#patternString

For a WebHookFilter that uses EVENT type, a comma-separated string that specifies one or more events. For example, the webhook filter ‘PUSH, PULL_REQUEST_CREATED, PULL_REQUEST_UPDATED` allows all push, pull request created, and pull request updated events to trigger a build.

For a WebHookFilter that uses any of the other filter types, a regular expression pattern. For example, a WebHookFilter that uses HEAD_REF for its type and the pattern ‘^refs/heads/` triggers a build when the head reference is a branch with a reference name refs/heads/branch-name.

Returns:

  • (String)


7341
7342
7343
7344
7345
7346
7347
# File 'lib/aws-sdk-codebuild/types.rb', line 7341

class WebhookFilter < Struct.new(
  :type,
  :pattern,
  :exclude_matched_pattern)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of webhook filter. There are six webhook filter types: EVENT, ACTOR_ACCOUNT_ID, HEAD_REF, BASE_REF, FILE_PATH, and COMMIT_MESSAGE.

EVENT

: A webhook event triggers a build when the provided pattern

matches one of five event types: `PUSH`, `PULL_REQUEST_CREATED`,
`PULL_REQUEST_UPDATED`, `PULL_REQUEST_REOPENED`, and
`PULL_REQUEST_MERGED`. The `EVENT` patterns are specified as a
comma-separated string. For example, `PUSH, PULL_REQUEST_CREATED,
PULL_REQUEST_UPDATED` filters all push, pull request created, and
pull request updated events.

<note markdown="1"> The `PULL_REQUEST_REOPENED` works with GitHub and GitHub
Enterprise only.

 </note>

ACTOR_ACCOUNT_ID

: A webhook event triggers a build when a GitHub, GitHub Enterprise,

or Bitbucket  ID matches the regular expression `pattern`.

HEAD_REF

: A webhook event triggers a build when the head reference matches

the regular expression `pattern`. For example,
`refs/heads/branch-name` and `refs/tags/tag-name`.

Works with GitHub and GitHub Enterprise push, GitHub and GitHub
Enterprise pull request, Bitbucket push, and Bitbucket pull
request events.

BASE_REF

: A webhook event triggers a build when the base reference matches

the regular expression `pattern`. For example,
`refs/heads/branch-name`.

<note markdown="1"> Works with pull request events only.

 </note>

FILE_PATH

: A webhook triggers a build when the path of a changed file matches

the regular expression `pattern`.

<note markdown="1"> Works with GitHub and Bitbucket events push and pull requests
events. Also works with GitHub Enterprise push events, but does
not work with GitHub Enterprise pull request events.

 </note>

COMMIT_MESSAGE

: A webhook triggers a build when the head commit message matches

the regular expression `pattern`.

<note markdown="1"> Works with GitHub and Bitbucket events push and pull requests
events. Also works with GitHub Enterprise push events, but does
not work with GitHub Enterprise pull request events.

 </note>

Returns:

  • (String)


7341
7342
7343
7344
7345
7346
7347
# File 'lib/aws-sdk-codebuild/types.rb', line 7341

class WebhookFilter < Struct.new(
  :type,
  :pattern,
  :exclude_matched_pattern)
  SENSITIVE = []
  include Aws::Structure
end